# coding: utf-8

"""
    PowerBot - Webservice for algotrading

    # TERMS AND CONDITIONS The PowerBot system provides B2B services for trading at intraday power markets. By using the PowerBot service, each user agrees to the terms and conditions of this licence: 1. The user confirms that they are familiar with the exchanges trading system and all relevant rules, is professionally qualified and in possession of a trading license for the relevant exchange. 2. The user will comply with the exchanges market rules (e.g. [EPEX Spot Market Rules](https://www.epexspot.com/en/downloads#rules-fees-processes) or [Nord Pool Market Rules](https://www.nordpoolgroup.com/trading/Rules-and-regulations/)) and will not endanger the exchange system at any time with heavy load from trading algorithms or by other use. 3. The user is aware of limits imposed by the exchange. 4. The user is solely liable for actions resulting from the use of PowerBot.   # INTRODUCTION PowerBot is a web-based software service enabling algorithmic trading on intraday power exchanges such as EPEX, Nord Pool, HUPX, BSP Southpool, TGE, OPCOM or ETPA. The service is straightforward to integrate in an existing software environment and provides a variety of programming interfaces for development of individual trading algorithms and software tools. Besides enabling fully automated intraday trading, it can be used to create tools for human traders providing relevant information and trading opportunities or can be integrated in existing software tools. For further details see https://www.powerbot-trading.com  ## Knowledge Base In addition to this API guide, please find the documentation at https://docs.powerbot-trading.com - the password will be provided by the PowerBot team. If not, please reach out to us at support@powerbot-trading.com  ## Endpoints The PowerBot service is available at the following REST endpoints:  | Instance      | Base URL for REST Endpoints                                      | |---------------|------------------------------------------------------------------| | EPEX          | https://staging.powerbot-trading.com/playground/epex/v2/api      | | Nord Pool     | https://staging.powerbot-trading.com/playground/nordpool/v2/api  | | HUPX          | https://staging.powerbot-trading.com/playground/hupx/v2/api      | | BSP Southpool | https://staging.powerbot-trading.com/playground/southpool/v2/api | | TGE           | https://staging.powerbot-trading.com/playground/tge/v2/api       | | IBEX          | https://staging.powerbot-trading.com/playground/ibex/v2/api      | | CROPEX        | https://staging.powerbot-trading.com/playground/cropex/v2/api    | | OPCOM         | https://staging.powerbot-trading.com/playground/opcom/v2/api     | | ETPA          | https://staging.powerbot-trading.com/playground/etpa/v2/api      | | BRM           | https://staging.powerbot-trading.com/playground/brm/v2/api       |  Access to endpoints is secured via an API Key, which needs to be passed as an \"api_key\" header in each request.   Notes on API Keys:  * API keys are specific to Test, Staging or Production.  * API keys are generated by the system administrator and need to be requested.  ## How to generate API clients (libraries) This OpenAPI specification can be used to generate API clients (programming libraries) for a wide range of programming languages using tools like [OpenAPI Generator](https://openapi-generator.tech/). A detailed guide can be found in the [knowledge base](https://docs.powerbot-trading.com/articles/getting-started/generating-clients/).  ## PowerBot Python client For Python, a ready-made client is also available on PyPI and can be downloaded locally via:  ```shell   pip install powerbot-client ```  ## Errors The API uses standard HTTP status codes to indicate the success or failure of the API call. The body of the response will be in JSON format as follows:  ``` {   \"message\": \"... an error message ...\" } ```  ## Paging The API uses offset and limit parameters for paged operations. An X-Total-Count header is added to responses to indicate the total number of items in a paged response.  ## API Rate Limiting The API limits the number of concurrent calls to 50 - when that limit is reached, the client will receive 503 http status codes (service unavailable) with the following text:  ``` {   \"message\": \"API rate limit exceeded\" } ``` Clients should ensure that they stay within the limit for concurrent API calls.    ## Additional code samples Additional information and code samples demonstrating the use of the API can be found at in our [knowledge base](https://docs.powerbot-trading.com/docs/programmatic-access/)  # noqa: E501

    The version of the OpenAPI document: 2.21.0-rc1
    Contact: office@powerbot-trading.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from powerbot_asyncio_client.configuration import Configuration


class ContractItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'exchange': 'str',
        'product': 'str',
        'contract_id': 'str',
        'type': 'ContractType',
        'revision_no': 'int',
        'state': 'str',
        'name': 'str',
        'delivery_start': 'datetime',
        'delivery_end': 'datetime',
        'contract_details': 'object',
        'delivery_areas': 'list[str]',
        'delivery_area_states': 'list[DeliveryAreaState]'
    }

    attribute_map = {
        'exchange': 'exchange',
        'product': 'product',
        'contract_id': 'contract_id',
        'type': 'type',
        'revision_no': 'revision_no',
        'state': 'state',
        'name': 'name',
        'delivery_start': 'delivery_start',
        'delivery_end': 'delivery_end',
        'contract_details': 'contract_details',
        'delivery_areas': 'delivery_areas',
        'delivery_area_states': 'delivery_area_states'
    }

    def __init__(self, exchange=None, product=None, contract_id=None, type=None, revision_no=None, state=None, name=None, delivery_start=None, delivery_end=None, contract_details=None, delivery_areas=None, delivery_area_states=None, local_vars_configuration=None):  # noqa: E501
        """ContractItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._exchange = None
        self._product = None
        self._contract_id = None
        self._type = None
        self._revision_no = None
        self._state = None
        self._name = None
        self._delivery_start = None
        self._delivery_end = None
        self._contract_details = None
        self._delivery_areas = None
        self._delivery_area_states = None
        self.discriminator = None

        if exchange is not None:
            self.exchange = exchange
        if product is not None:
            self.product = product
        if contract_id is not None:
            self.contract_id = contract_id
        if type is not None:
            self.type = type
        if revision_no is not None:
            self.revision_no = revision_no
        if state is not None:
            self.state = state
        if name is not None:
            self.name = name
        if delivery_start is not None:
            self.delivery_start = delivery_start
        if delivery_end is not None:
            self.delivery_end = delivery_end
        if contract_details is not None:
            self.contract_details = contract_details
        if delivery_areas is not None:
            self.delivery_areas = delivery_areas
        if delivery_area_states is not None:
            self.delivery_area_states = delivery_area_states

    @property
    def exchange(self):
        """Gets the exchange of this ContractItem.  # noqa: E501


        :return: The exchange of this ContractItem.  # noqa: E501
        :rtype: str
        """
        return self._exchange

    @exchange.setter
    def exchange(self, exchange):
        """Sets the exchange of this ContractItem.


        :param exchange: The exchange of this ContractItem.  # noqa: E501
        :type exchange: str
        """

        self._exchange = exchange

    @property
    def product(self):
        """Gets the product of this ContractItem.  # noqa: E501


        :return: The product of this ContractItem.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this ContractItem.


        :param product: The product of this ContractItem.  # noqa: E501
        :type product: str
        """

        self._product = product

    @property
    def contract_id(self):
        """Gets the contract_id of this ContractItem.  # noqa: E501

        The contract's unique id  # noqa: E501

        :return: The contract_id of this ContractItem.  # noqa: E501
        :rtype: str
        """
        return self._contract_id

    @contract_id.setter
    def contract_id(self, contract_id):
        """Sets the contract_id of this ContractItem.

        The contract's unique id  # noqa: E501

        :param contract_id: The contract_id of this ContractItem.  # noqa: E501
        :type contract_id: str
        """

        self._contract_id = contract_id

    @property
    def type(self):
        """Gets the type of this ContractItem.  # noqa: E501


        :return: The type of this ContractItem.  # noqa: E501
        :rtype: ContractType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ContractItem.


        :param type: The type of this ContractItem.  # noqa: E501
        :type type: ContractType
        """

        self._type = type

    @property
    def revision_no(self):
        """Gets the revision_no of this ContractItem.  # noqa: E501


        :return: The revision_no of this ContractItem.  # noqa: E501
        :rtype: int
        """
        return self._revision_no

    @revision_no.setter
    def revision_no(self, revision_no):
        """Sets the revision_no of this ContractItem.


        :param revision_no: The revision_no of this ContractItem.  # noqa: E501
        :type revision_no: int
        """

        self._revision_no = revision_no

    @property
    def state(self):
        """Gets the state of this ContractItem.  # noqa: E501


        :return: The state of this ContractItem.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ContractItem.


        :param state: The state of this ContractItem.  # noqa: E501
        :type state: str
        """

        self._state = state

    @property
    def name(self):
        """Gets the name of this ContractItem.  # noqa: E501

        The name of the contract  # noqa: E501

        :return: The name of this ContractItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ContractItem.

        The name of the contract  # noqa: E501

        :param name: The name of this ContractItem.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def delivery_start(self):
        """Gets the delivery_start of this ContractItem.  # noqa: E501

        The delivery start time (UTC) of the contract  # noqa: E501

        :return: The delivery_start of this ContractItem.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_start

    @delivery_start.setter
    def delivery_start(self, delivery_start):
        """Sets the delivery_start of this ContractItem.

        The delivery start time (UTC) of the contract  # noqa: E501

        :param delivery_start: The delivery_start of this ContractItem.  # noqa: E501
        :type delivery_start: datetime
        """

        self._delivery_start = delivery_start

    @property
    def delivery_end(self):
        """Gets the delivery_end of this ContractItem.  # noqa: E501

        The delivery end time (UTC) of the contract  # noqa: E501

        :return: The delivery_end of this ContractItem.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_end

    @delivery_end.setter
    def delivery_end(self, delivery_end):
        """Sets the delivery_end of this ContractItem.

        The delivery end time (UTC) of the contract  # noqa: E501

        :param delivery_end: The delivery_end of this ContractItem.  # noqa: E501
        :type delivery_end: datetime
        """

        self._delivery_end = delivery_end

    @property
    def contract_details(self):
        """Gets the contract_details of this ContractItem.  # noqa: E501


        :return: The contract_details of this ContractItem.  # noqa: E501
        :rtype: object
        """
        return self._contract_details

    @contract_details.setter
    def contract_details(self, contract_details):
        """Sets the contract_details of this ContractItem.


        :param contract_details: The contract_details of this ContractItem.  # noqa: E501
        :type contract_details: object
        """

        self._contract_details = contract_details

    @property
    def delivery_areas(self):
        """Gets the delivery_areas of this ContractItem.  # noqa: E501


        :return: The delivery_areas of this ContractItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._delivery_areas

    @delivery_areas.setter
    def delivery_areas(self, delivery_areas):
        """Sets the delivery_areas of this ContractItem.


        :param delivery_areas: The delivery_areas of this ContractItem.  # noqa: E501
        :type delivery_areas: list[str]
        """

        self._delivery_areas = delivery_areas

    @property
    def delivery_area_states(self):
        """Gets the delivery_area_states of this ContractItem.  # noqa: E501


        :return: The delivery_area_states of this ContractItem.  # noqa: E501
        :rtype: list[DeliveryAreaState]
        """
        return self._delivery_area_states

    @delivery_area_states.setter
    def delivery_area_states(self, delivery_area_states):
        """Sets the delivery_area_states of this ContractItem.


        :param delivery_area_states: The delivery_area_states of this ContractItem.  # noqa: E501
        :type delivery_area_states: list[DeliveryAreaState]
        """

        self._delivery_area_states = delivery_area_states

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContractItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ContractItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    PowerBot - Webservice for algotrading

    # TERMS AND CONDITIONS The PowerBot system provides B2B services for trading at intraday power markets. By using the PowerBot service, each user agrees to the terms and conditions of this licence: 1. The user confirms that they are familiar with the exchanges trading system and all relevant rules, is professionally qualified and in possession of a trading license for the relevant exchange. 2. The user will comply with the exchanges market rules (e.g. [EPEX Spot Market Rules](https://www.epexspot.com/en/downloads#rules-fees-processes) or [Nord Pool Market Rules](https://www.nordpoolgroup.com/trading/Rules-and-regulations/)) and will not endanger the exchange system at any time with heavy load from trading algorithms or by other use. 3. The user is aware of limits imposed by the exchange. 4. The user is solely liable for actions resulting from the use of PowerBot.   # INTRODUCTION PowerBot is a web-based software service enabling algorithmic trading on intraday power exchanges such as EPEX, Nord Pool, HUPX, BSP Southpool, TGE, OPCOM or ETPA. The service is straightforward to integrate in an existing software environment and provides a variety of programming interfaces for development of individual trading algorithms and software tools. Besides enabling fully automated intraday trading, it can be used to create tools for human traders providing relevant information and trading opportunities or can be integrated in existing software tools. For further details see https://www.powerbot-trading.com  ## Knowledge Base In addition to this API guide, please find the documentation at https://docs.powerbot-trading.com - the password will be provided by the PowerBot team. If not, please reach out to us at support@powerbot-trading.com  ## Endpoints The PowerBot service is available at the following REST endpoints:  | Instance      | Base URL for REST Endpoints                                      | |---------------|------------------------------------------------------------------| | EPEX          | https://staging.powerbot-trading.com/playground/epex/v2/api      | | Nord Pool     | https://staging.powerbot-trading.com/playground/nordpool/v2/api  | | HUPX          | https://staging.powerbot-trading.com/playground/hupx/v2/api      | | BSP Southpool | https://staging.powerbot-trading.com/playground/southpool/v2/api | | TGE           | https://staging.powerbot-trading.com/playground/tge/v2/api       | | IBEX          | https://staging.powerbot-trading.com/playground/ibex/v2/api      | | CROPEX        | https://staging.powerbot-trading.com/playground/cropex/v2/api    | | OPCOM         | https://staging.powerbot-trading.com/playground/opcom/v2/api     | | ETPA          | https://staging.powerbot-trading.com/playground/etpa/v2/api      | | BRM           | https://staging.powerbot-trading.com/playground/brm/v2/api       |  Access to endpoints is secured via an API Key, which needs to be passed as an \"api_key\" header in each request.   Notes on API Keys:  * API keys are specific to Test, Staging or Production.  * API keys are generated by the system administrator and need to be requested.  ## How to generate API clients (libraries) This OpenAPI specification can be used to generate API clients (programming libraries) for a wide range of programming languages using tools like [OpenAPI Generator](https://openapi-generator.tech/). A detailed guide can be found in the [knowledge base](https://docs.powerbot-trading.com/articles/getting-started/generating-clients/).  ## PowerBot Python client For Python, a ready-made client is also available on PyPI and can be downloaded locally via:  ```shell   pip install powerbot-client ```  ## Errors The API uses standard HTTP status codes to indicate the success or failure of the API call. The body of the response will be in JSON format as follows:  ``` {   \"message\": \"... an error message ...\" } ```  ## Paging The API uses offset and limit parameters for paged operations. An X-Total-Count header is added to responses to indicate the total number of items in a paged response.  ## API Rate Limiting The API limits the number of concurrent calls to 50 - when that limit is reached, the client will receive 503 http status codes (service unavailable) with the following text:  ``` {   \"message\": \"API rate limit exceeded\" } ``` Clients should ensure that they stay within the limit for concurrent API calls.    ## Additional code samples Additional information and code samples demonstrating the use of the API can be found at in our [knowledge base](https://docs.powerbot-trading.com/docs/programmatic-access/)  # noqa: E501

    The version of the OpenAPI document: 2.21.0-rc1
    Contact: office@powerbot-trading.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from powerbot_asyncio_client.configuration import Configuration


class Capacity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'api_timestamp': 'datetime',
        'timestamp': 'datetime',
        'from_delivery_area': 'str',
        'to_delivery_area': 'str',
        'revision': 'int',
        'delivery_start': 'datetime',
        'delivery_end': 'datetime',
        '_in': 'float',
        'out': 'float'
    }

    attribute_map = {
        'api_timestamp': 'api_timestamp',
        'timestamp': 'timestamp',
        'from_delivery_area': 'from_delivery_area',
        'to_delivery_area': 'to_delivery_area',
        'revision': 'revision',
        'delivery_start': 'delivery_start',
        'delivery_end': 'delivery_end',
        '_in': 'in',
        'out': 'out'
    }

    def __init__(self, api_timestamp=None, timestamp=None, from_delivery_area=None, to_delivery_area=None, revision=None, delivery_start=None, delivery_end=None, _in=None, out=None, local_vars_configuration=None):  # noqa: E501
        """Capacity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._api_timestamp = None
        self._timestamp = None
        self._from_delivery_area = None
        self._to_delivery_area = None
        self._revision = None
        self._delivery_start = None
        self._delivery_end = None
        self.__in = None
        self._out = None
        self.discriminator = None

        if api_timestamp is not None:
            self.api_timestamp = api_timestamp
        if timestamp is not None:
            self.timestamp = timestamp
        self.from_delivery_area = from_delivery_area
        self.to_delivery_area = to_delivery_area
        if revision is not None:
            self.revision = revision
        self.delivery_start = delivery_start
        self.delivery_end = delivery_end
        self._in = _in
        self.out = out

    @property
    def api_timestamp(self):
        """Gets the api_timestamp of this Capacity.  # noqa: E501

        DEPRECATED: Use timestamp instead. The timestamp of the entry being received by the PowerBot API  # noqa: E501

        :return: The api_timestamp of this Capacity.  # noqa: E501
        :rtype: datetime
        """
        return self._api_timestamp

    @api_timestamp.setter
    def api_timestamp(self, api_timestamp):
        """Sets the api_timestamp of this Capacity.

        DEPRECATED: Use timestamp instead. The timestamp of the entry being received by the PowerBot API  # noqa: E501

        :param api_timestamp: The api_timestamp of this Capacity.  # noqa: E501
        :type api_timestamp: datetime
        """

        self._api_timestamp = api_timestamp

    @property
    def timestamp(self):
        """Gets the timestamp of this Capacity.  # noqa: E501

        The timestamp when the data was sent from the capacity system of the exchange  # noqa: E501

        :return: The timestamp of this Capacity.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this Capacity.

        The timestamp when the data was sent from the capacity system of the exchange  # noqa: E501

        :param timestamp: The timestamp of this Capacity.  # noqa: E501
        :type timestamp: datetime
        """

        self._timestamp = timestamp

    @property
    def from_delivery_area(self):
        """Gets the from_delivery_area of this Capacity.  # noqa: E501

        EIC of the outgoing area  # noqa: E501

        :return: The from_delivery_area of this Capacity.  # noqa: E501
        :rtype: str
        """
        return self._from_delivery_area

    @from_delivery_area.setter
    def from_delivery_area(self, from_delivery_area):
        """Sets the from_delivery_area of this Capacity.

        EIC of the outgoing area  # noqa: E501

        :param from_delivery_area: The from_delivery_area of this Capacity.  # noqa: E501
        :type from_delivery_area: str
        """
        if self.local_vars_configuration.client_side_validation and from_delivery_area is None:  # noqa: E501
            raise ValueError("Invalid value for `from_delivery_area`, must not be `None`")  # noqa: E501

        self._from_delivery_area = from_delivery_area

    @property
    def to_delivery_area(self):
        """Gets the to_delivery_area of this Capacity.  # noqa: E501

        EIC of the incoming area  # noqa: E501

        :return: The to_delivery_area of this Capacity.  # noqa: E501
        :rtype: str
        """
        return self._to_delivery_area

    @to_delivery_area.setter
    def to_delivery_area(self, to_delivery_area):
        """Sets the to_delivery_area of this Capacity.

        EIC of the incoming area  # noqa: E501

        :param to_delivery_area: The to_delivery_area of this Capacity.  # noqa: E501
        :type to_delivery_area: str
        """
        if self.local_vars_configuration.client_side_validation and to_delivery_area is None:  # noqa: E501
            raise ValueError("Invalid value for `to_delivery_area`, must not be `None`")  # noqa: E501

        self._to_delivery_area = to_delivery_area

    @property
    def revision(self):
        """Gets the revision of this Capacity.  # noqa: E501

        Revision number of the entry  # noqa: E501

        :return: The revision of this Capacity.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this Capacity.

        Revision number of the entry  # noqa: E501

        :param revision: The revision of this Capacity.  # noqa: E501
        :type revision: int
        """

        self._revision = revision

    @property
    def delivery_start(self):
        """Gets the delivery_start of this Capacity.  # noqa: E501

        Delivery start date-time  # noqa: E501

        :return: The delivery_start of this Capacity.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_start

    @delivery_start.setter
    def delivery_start(self, delivery_start):
        """Sets the delivery_start of this Capacity.

        Delivery start date-time  # noqa: E501

        :param delivery_start: The delivery_start of this Capacity.  # noqa: E501
        :type delivery_start: datetime
        """
        if self.local_vars_configuration.client_side_validation and delivery_start is None:  # noqa: E501
            raise ValueError("Invalid value for `delivery_start`, must not be `None`")  # noqa: E501

        self._delivery_start = delivery_start

    @property
    def delivery_end(self):
        """Gets the delivery_end of this Capacity.  # noqa: E501

        Delivery end date-time  # noqa: E501

        :return: The delivery_end of this Capacity.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_end

    @delivery_end.setter
    def delivery_end(self, delivery_end):
        """Sets the delivery_end of this Capacity.

        Delivery end date-time  # noqa: E501

        :param delivery_end: The delivery_end of this Capacity.  # noqa: E501
        :type delivery_end: datetime
        """
        if self.local_vars_configuration.client_side_validation and delivery_end is None:  # noqa: E501
            raise ValueError("Invalid value for `delivery_end`, must not be `None`")  # noqa: E501

        self._delivery_end = delivery_end

    @property
    def _in(self):
        """Gets the _in of this Capacity.  # noqa: E501

        The ATC value from \"to_delivery_area\" to \"from_delivery_area\"  # noqa: E501

        :return: The _in of this Capacity.  # noqa: E501
        :rtype: float
        """
        return self.__in

    @_in.setter
    def _in(self, _in):
        """Sets the _in of this Capacity.

        The ATC value from \"to_delivery_area\" to \"from_delivery_area\"  # noqa: E501

        :param _in: The _in of this Capacity.  # noqa: E501
        :type _in: float
        """
        if self.local_vars_configuration.client_side_validation and _in is None:  # noqa: E501
            raise ValueError("Invalid value for `_in`, must not be `None`")  # noqa: E501

        self.__in = _in

    @property
    def out(self):
        """Gets the out of this Capacity.  # noqa: E501

        The ATC value from \"from_delivery_area\" to \"to_delivery_area\"  # noqa: E501

        :return: The out of this Capacity.  # noqa: E501
        :rtype: float
        """
        return self._out

    @out.setter
    def out(self, out):
        """Sets the out of this Capacity.

        The ATC value from \"from_delivery_area\" to \"to_delivery_area\"  # noqa: E501

        :param out: The out of this Capacity.  # noqa: E501
        :type out: float
        """
        if self.local_vars_configuration.client_side_validation and out is None:  # noqa: E501
            raise ValueError("Invalid value for `out`, must not be `None`")  # noqa: E501

        self._out = out

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Capacity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Capacity):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    PowerBot - Webservice for algotrading

    # TERMS AND CONDITIONS The PowerBot system provides B2B services for trading at intraday power markets. By using the PowerBot service, each user agrees to the terms and conditions of this licence: 1. The user confirms that they are familiar with the exchanges trading system and all relevant rules, is professionally qualified and in possession of a trading license for the relevant exchange. 2. The user will comply with the exchanges market rules (e.g. [EPEX Spot Market Rules](https://www.epexspot.com/en/downloads#rules-fees-processes) or [Nord Pool Market Rules](https://www.nordpoolgroup.com/trading/Rules-and-regulations/)) and will not endanger the exchange system at any time with heavy load from trading algorithms or by other use. 3. The user is aware of limits imposed by the exchange. 4. The user is solely liable for actions resulting from the use of PowerBot.   # INTRODUCTION PowerBot is a web-based software service enabling algorithmic trading on intraday power exchanges such as EPEX, Nord Pool, HUPX, BSP Southpool, TGE, OPCOM or ETPA. The service is straightforward to integrate in an existing software environment and provides a variety of programming interfaces for development of individual trading algorithms and software tools. Besides enabling fully automated intraday trading, it can be used to create tools for human traders providing relevant information and trading opportunities or can be integrated in existing software tools. For further details see https://www.powerbot-trading.com  ## Knowledge Base In addition to this API guide, please find the documentation at https://docs.powerbot-trading.com - the password will be provided by the PowerBot team. If not, please reach out to us at support@powerbot-trading.com  ## Endpoints The PowerBot service is available at the following REST endpoints:  | Instance      | Base URL for REST Endpoints                                      | |---------------|------------------------------------------------------------------| | EPEX          | https://staging.powerbot-trading.com/playground/epex/v2/api      | | Nord Pool     | https://staging.powerbot-trading.com/playground/nordpool/v2/api  | | HUPX          | https://staging.powerbot-trading.com/playground/hupx/v2/api      | | BSP Southpool | https://staging.powerbot-trading.com/playground/southpool/v2/api | | TGE           | https://staging.powerbot-trading.com/playground/tge/v2/api       | | IBEX          | https://staging.powerbot-trading.com/playground/ibex/v2/api      | | CROPEX        | https://staging.powerbot-trading.com/playground/cropex/v2/api    | | OPCOM         | https://staging.powerbot-trading.com/playground/opcom/v2/api     | | ETPA          | https://staging.powerbot-trading.com/playground/etpa/v2/api      | | BRM           | https://staging.powerbot-trading.com/playground/brm/v2/api       |  Access to endpoints is secured via an API Key, which needs to be passed as an \"api_key\" header in each request.   Notes on API Keys:  * API keys are specific to Test, Staging or Production.  * API keys are generated by the system administrator and need to be requested.  ## How to generate API clients (libraries) This OpenAPI specification can be used to generate API clients (programming libraries) for a wide range of programming languages using tools like [OpenAPI Generator](https://openapi-generator.tech/). A detailed guide can be found in the [knowledge base](https://docs.powerbot-trading.com/articles/getting-started/generating-clients/).  ## PowerBot Python client For Python, a ready-made client is also available on PyPI and can be downloaded locally via:  ```shell   pip install powerbot-client ```  ## Errors The API uses standard HTTP status codes to indicate the success or failure of the API call. The body of the response will be in JSON format as follows:  ``` {   \"message\": \"... an error message ...\" } ```  ## Paging The API uses offset and limit parameters for paged operations. An X-Total-Count header is added to responses to indicate the total number of items in a paged response.  ## API Rate Limiting The API limits the number of concurrent calls to 50 - when that limit is reached, the client will receive 503 http status codes (service unavailable) with the following text:  ``` {   \"message\": \"API rate limit exceeded\" } ``` Clients should ensure that they stay within the limit for concurrent API calls.    ## Additional code samples Additional information and code samples demonstrating the use of the API can be found at in our [knowledge base](https://docs.powerbot-trading.com/docs/programmatic-access/)  # noqa: E501

    The version of the OpenAPI document: 2.21.0-rc1
    Contact: office@powerbot-trading.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from powerbot_asyncio_client.api_client import ApiClient
from powerbot_asyncio_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ReportApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_report_csv_for_period(self, delivery_area, delivery_day_from, delivery_day_to, **kwargs):  # noqa: E501
        """Create CSV trading report  # noqa: E501

        Creates a detailed trading report in CSV format for a delivery area and a given delivery period. However, as the CSV format is two-dimensional, this report delivers less data compared to the regular report method.  As the generation of the report requires a lot of calculations, please use wisely. The maximum period you can request is limited to 31 days. The request retrieves an array of portfolios and can thus deliver data for one or more portfolios at the same time. However, some data (e.g. positions) cannot be aggregated for portfolios and will thus not show up, if you request data from more than one portfolio. The report can use filters for clOrdrId and txt, which means that only trades for which the filter is valid are included in the report.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_report_csv_for_period(delivery_area, delivery_day_from, delivery_day_to, async_req=True)
        >>> result = thread.get()

        :param delivery_area: The EIC of the delivery area (required)
        :type delivery_area: str
        :param delivery_day_from: The day the report is for (example \"2018-10-23\") (required)
        :type delivery_day_from: date
        :param delivery_day_to: The day the report is for (example \"2018-10-30\") (required)
        :type delivery_day_to: date
        :param portfolio_id:
        :type portfolio_id: list[str]
        :param cl_ordr_id: Show only those trades related to orders with a specific 'client order id' (something like 'your reference' which you can submit) together with an order
        :type cl_ordr_id: str
        :param txt: Show only those trades related to orders with a specific 'custom text'. Similar to the clOrdrId, you can submit a string inside the 'txt' attribute of an order which helps you to identify trades originating from a specific order at a later point
        :type txt: str
        :param column_separator:
        :type column_separator: str
        :param comma_separator:
        :type comma_separator: str
        :param txt_matching_mode:
        :type txt_matching_mode: TextMatchingMode
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: str
        """
        kwargs['_return_http_data_only'] = True
        return self.get_report_csv_for_period_with_http_info(delivery_area, delivery_day_from, delivery_day_to, **kwargs)  # noqa: E501

    def get_report_csv_for_period_with_http_info(self, delivery_area, delivery_day_from, delivery_day_to, **kwargs):  # noqa: E501
        """Create CSV trading report  # noqa: E501

        Creates a detailed trading report in CSV format for a delivery area and a given delivery period. However, as the CSV format is two-dimensional, this report delivers less data compared to the regular report method.  As the generation of the report requires a lot of calculations, please use wisely. The maximum period you can request is limited to 31 days. The request retrieves an array of portfolios and can thus deliver data for one or more portfolios at the same time. However, some data (e.g. positions) cannot be aggregated for portfolios and will thus not show up, if you request data from more than one portfolio. The report can use filters for clOrdrId and txt, which means that only trades for which the filter is valid are included in the report.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_report_csv_for_period_with_http_info(delivery_area, delivery_day_from, delivery_day_to, async_req=True)
        >>> result = thread.get()

        :param delivery_area: The EIC of the delivery area (required)
        :type delivery_area: str
        :param delivery_day_from: The day the report is for (example \"2018-10-23\") (required)
        :type delivery_day_from: date
        :param delivery_day_to: The day the report is for (example \"2018-10-30\") (required)
        :type delivery_day_to: date
        :param portfolio_id:
        :type portfolio_id: list[str]
        :param cl_ordr_id: Show only those trades related to orders with a specific 'client order id' (something like 'your reference' which you can submit) together with an order
        :type cl_ordr_id: str
        :param txt: Show only those trades related to orders with a specific 'custom text'. Similar to the clOrdrId, you can submit a string inside the 'txt' attribute of an order which helps you to identify trades originating from a specific order at a later point
        :type txt: str
        :param column_separator:
        :type column_separator: str
        :param comma_separator:
        :type comma_separator: str
        :param txt_matching_mode:
        :type txt_matching_mode: TextMatchingMode
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(str, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'delivery_area',
            'delivery_day_from',
            'delivery_day_to',
            'portfolio_id',
            'cl_ordr_id',
            'txt',
            'column_separator',
            'comma_separator',
            'txt_matching_mode'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_report_csv_for_period" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'delivery_area' is set
        if self.api_client.client_side_validation and local_var_params.get('delivery_area') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `delivery_area` when calling `get_report_csv_for_period`")  # noqa: E501
        # verify the required parameter 'delivery_day_from' is set
        if self.api_client.client_side_validation and local_var_params.get('delivery_day_from') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `delivery_day_from` when calling `get_report_csv_for_period`")  # noqa: E501
        # verify the required parameter 'delivery_day_to' is set
        if self.api_client.client_side_validation and local_var_params.get('delivery_day_to') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `delivery_day_to` when calling `get_report_csv_for_period`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'delivery_area' in local_var_params:
            path_params['delivery_area'] = local_var_params['delivery_area']  # noqa: E501

        query_params = []
        if local_var_params.get('portfolio_id') is not None:  # noqa: E501
            query_params.append(('portfolio_id', local_var_params['portfolio_id']))  # noqa: E501
            collection_formats['portfolio_id'] = 'csv'  # noqa: E501
        if local_var_params.get('delivery_day_from') is not None:  # noqa: E501
            query_params.append(('delivery_day_from', local_var_params['delivery_day_from']))  # noqa: E501
        if local_var_params.get('delivery_day_to') is not None:  # noqa: E501
            query_params.append(('delivery_day_to', local_var_params['delivery_day_to']))  # noqa: E501
        if local_var_params.get('cl_ordr_id') is not None:  # noqa: E501
            query_params.append(('clOrdrId', local_var_params['cl_ordr_id']))  # noqa: E501
        if local_var_params.get('txt') is not None:  # noqa: E501
            query_params.append(('txt', local_var_params['txt']))  # noqa: E501
        if local_var_params.get('column_separator') is not None:  # noqa: E501
            query_params.append(('column_separator', local_var_params['column_separator']))  # noqa: E501
        if local_var_params.get('comma_separator') is not None:  # noqa: E501
            query_params.append(('comma_separator', local_var_params['comma_separator']))  # noqa: E501
        if local_var_params.get('txt_matching_mode') is not None:  # noqa: E501
            query_params.append(('txt_matching_mode', local_var_params['txt_matching_mode']))  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_security']  # noqa: E501

        response_types_map = {
            200: "str",
        }

        return self.api_client.call_api(
            '/report/{delivery_area}/csv', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def get_report_for_period(self, delivery_area, **kwargs):  # noqa: E501
        """Create JSON trading report  # noqa: E501

        Creates a detailed trading report for a delivery area and a given delivery period, which contains all relevant information.  As the generation of the report requires a lot of calculations, please use wisely.  The time period you can request is limited to a maximum of 31 days. There are two options to set the time period, you must use exactly one: * Timestamp: Use parameters 'delivery_from' and 'delivery_to'. Both fields must be set. Only full hours are considered. * Date: Within the date option the mandatory parameters are 'delivery_day_from' and 'delivery_day_to'. Optionally 'delivery_day_from_starting_hour' and 'delivery_day_to_ending_hour' can be set.  The request retrieves an array of portfolios and can thus deliver data for one or more portfolios at the same time. However, some data (e.g. positions) cannot be aggregated for portfolios and will therefore not show up, if you request data from more than one portfolio. Optionally, the report can include the trades for the portfolio(s) that have a delivery period within the report period. In addition, the report can use filters for 'clOrdrId' and 'txt', which means that only trades for which the filter is valid are included in the report.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_report_for_period(delivery_area, async_req=True)
        >>> result = thread.get()

        :param delivery_area: The EIC of the delivery area (required)
        :type delivery_area: str
        :param portfolio_id:
        :type portfolio_id: list[str]
        :param delivery_day_from: The day the report starts. This field is mutually exclusive with 'delivery_from' and 'delivery_to'.
        :type delivery_day_from: date
        :param delivery_day_to: The day the report ends. This field is mutually exclusive with 'delivery_from' and 'delivery_to'.
        :type delivery_day_to: date
        :param delivery_day_from_starting_hour: The starting hour of the report (0 = midnight)
        :type delivery_day_from_starting_hour: int
        :param delivery_day_to_ending_hour: The ending hour of the report (0 = midnight)
        :type delivery_day_to_ending_hour: int
        :param cl_ordr_id: Use only trades in the calculation of the report, which are related to orders with a specific 'client order id' (something like 'your reference' which you can submit) together with an order
        :type cl_ordr_id: str
        :param txt: Use only trades in the calculation of the report, which are related to orders with a specific 'custom text'. Similar to the clOrdrId, you can submit a string inside the 'txt' attribute of an order which helps you to identify trades originating from a specific order at a later point
        :type txt: str
        :param with_trades:
        :type with_trades: bool
        :param txt_matching_mode:
        :type txt_matching_mode: TextMatchingMode
        :param with_auction_positions: Setting this parameter to true will add intraday and day-ahead auction positions to the report.
        :type with_auction_positions: bool
        :param with_auction_trades: Setting this parameter to true will add intraday and day-ahead auction trades to the report.
        :type with_auction_trades: bool
        :param delivery_from: The timestamp indicating when the report starts. This field is mutually exclusive with 'delivery_day_from' and 'delivery_day_to'.
        :type delivery_from: datetime
        :param delivery_to: The timestamp indicating when the report ends. This field is mutually exclusive with 'delivery_day_from' and 'delivery_day_to'.
        :type delivery_to: datetime
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Report
        """
        kwargs['_return_http_data_only'] = True
        return self.get_report_for_period_with_http_info(delivery_area, **kwargs)  # noqa: E501

    def get_report_for_period_with_http_info(self, delivery_area, **kwargs):  # noqa: E501
        """Create JSON trading report  # noqa: E501

        Creates a detailed trading report for a delivery area and a given delivery period, which contains all relevant information.  As the generation of the report requires a lot of calculations, please use wisely.  The time period you can request is limited to a maximum of 31 days. There are two options to set the time period, you must use exactly one: * Timestamp: Use parameters 'delivery_from' and 'delivery_to'. Both fields must be set. Only full hours are considered. * Date: Within the date option the mandatory parameters are 'delivery_day_from' and 'delivery_day_to'. Optionally 'delivery_day_from_starting_hour' and 'delivery_day_to_ending_hour' can be set.  The request retrieves an array of portfolios and can thus deliver data for one or more portfolios at the same time. However, some data (e.g. positions) cannot be aggregated for portfolios and will therefore not show up, if you request data from more than one portfolio. Optionally, the report can include the trades for the portfolio(s) that have a delivery period within the report period. In addition, the report can use filters for 'clOrdrId' and 'txt', which means that only trades for which the filter is valid are included in the report.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_report_for_period_with_http_info(delivery_area, async_req=True)
        >>> result = thread.get()

        :param delivery_area: The EIC of the delivery area (required)
        :type delivery_area: str
        :param portfolio_id:
        :type portfolio_id: list[str]
        :param delivery_day_from: The day the report starts. This field is mutually exclusive with 'delivery_from' and 'delivery_to'.
        :type delivery_day_from: date
        :param delivery_day_to: The day the report ends. This field is mutually exclusive with 'delivery_from' and 'delivery_to'.
        :type delivery_day_to: date
        :param delivery_day_from_starting_hour: The starting hour of the report (0 = midnight)
        :type delivery_day_from_starting_hour: int
        :param delivery_day_to_ending_hour: The ending hour of the report (0 = midnight)
        :type delivery_day_to_ending_hour: int
        :param cl_ordr_id: Use only trades in the calculation of the report, which are related to orders with a specific 'client order id' (something like 'your reference' which you can submit) together with an order
        :type cl_ordr_id: str
        :param txt: Use only trades in the calculation of the report, which are related to orders with a specific 'custom text'. Similar to the clOrdrId, you can submit a string inside the 'txt' attribute of an order which helps you to identify trades originating from a specific order at a later point
        :type txt: str
        :param with_trades:
        :type with_trades: bool
        :param txt_matching_mode:
        :type txt_matching_mode: TextMatchingMode
        :param with_auction_positions: Setting this parameter to true will add intraday and day-ahead auction positions to the report.
        :type with_auction_positions: bool
        :param with_auction_trades: Setting this parameter to true will add intraday and day-ahead auction trades to the report.
        :type with_auction_trades: bool
        :param delivery_from: The timestamp indicating when the report starts. This field is mutually exclusive with 'delivery_day_from' and 'delivery_day_to'.
        :type delivery_from: datetime
        :param delivery_to: The timestamp indicating when the report ends. This field is mutually exclusive with 'delivery_day_from' and 'delivery_day_to'.
        :type delivery_to: datetime
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Report, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'delivery_area',
            'portfolio_id',
            'delivery_day_from',
            'delivery_day_to',
            'delivery_day_from_starting_hour',
            'delivery_day_to_ending_hour',
            'cl_ordr_id',
            'txt',
            'with_trades',
            'txt_matching_mode',
            'with_auction_positions',
            'with_auction_trades',
            'delivery_from',
            'delivery_to'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_report_for_period" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'delivery_area' is set
        if self.api_client.client_side_validation and local_var_params.get('delivery_area') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `delivery_area` when calling `get_report_for_period`")  # noqa: E501

        if self.api_client.client_side_validation and 'delivery_day_from_starting_hour' in local_var_params and local_var_params['delivery_day_from_starting_hour'] > 23:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `delivery_day_from_starting_hour` when calling `get_report_for_period`, must be a value less than or equal to `23`")  # noqa: E501
        if self.api_client.client_side_validation and 'delivery_day_from_starting_hour' in local_var_params and local_var_params['delivery_day_from_starting_hour'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `delivery_day_from_starting_hour` when calling `get_report_for_period`, must be a value greater than or equal to `0`")  # noqa: E501
        if self.api_client.client_side_validation and 'delivery_day_to_ending_hour' in local_var_params and local_var_params['delivery_day_to_ending_hour'] > 23:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `delivery_day_to_ending_hour` when calling `get_report_for_period`, must be a value less than or equal to `23`")  # noqa: E501
        if self.api_client.client_side_validation and 'delivery_day_to_ending_hour' in local_var_params and local_var_params['delivery_day_to_ending_hour'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `delivery_day_to_ending_hour` when calling `get_report_for_period`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'delivery_area' in local_var_params:
            path_params['delivery_area'] = local_var_params['delivery_area']  # noqa: E501

        query_params = []
        if local_var_params.get('portfolio_id') is not None:  # noqa: E501
            query_params.append(('portfolio_id', local_var_params['portfolio_id']))  # noqa: E501
            collection_formats['portfolio_id'] = 'csv'  # noqa: E501
        if local_var_params.get('delivery_day_from') is not None:  # noqa: E501
            query_params.append(('delivery_day_from', local_var_params['delivery_day_from']))  # noqa: E501
        if local_var_params.get('delivery_day_to') is not None:  # noqa: E501
            query_params.append(('delivery_day_to', local_var_params['delivery_day_to']))  # noqa: E501
        if local_var_params.get('delivery_day_from_starting_hour') is not None:  # noqa: E501
            query_params.append(('delivery_day_from_starting_hour', local_var_params['delivery_day_from_starting_hour']))  # noqa: E501
        if local_var_params.get('delivery_day_to_ending_hour') is not None:  # noqa: E501
            query_params.append(('delivery_day_to_ending_hour', local_var_params['delivery_day_to_ending_hour']))  # noqa: E501
        if local_var_params.get('cl_ordr_id') is not None:  # noqa: E501
            query_params.append(('clOrdrId', local_var_params['cl_ordr_id']))  # noqa: E501
        if local_var_params.get('txt') is not None:  # noqa: E501
            query_params.append(('txt', local_var_params['txt']))  # noqa: E501
        if local_var_params.get('with_trades') is not None:  # noqa: E501
            query_params.append(('with_trades', local_var_params['with_trades']))  # noqa: E501
        if local_var_params.get('txt_matching_mode') is not None:  # noqa: E501
            query_params.append(('txt_matching_mode', local_var_params['txt_matching_mode']))  # noqa: E501
        if local_var_params.get('with_auction_positions') is not None:  # noqa: E501
            query_params.append(('with_auction_positions', local_var_params['with_auction_positions']))  # noqa: E501
        if local_var_params.get('with_auction_trades') is not None:  # noqa: E501
            query_params.append(('with_auction_trades', local_var_params['with_auction_trades']))  # noqa: E501
        if local_var_params.get('delivery_from') is not None:  # noqa: E501
            query_params.append(('delivery_from', local_var_params['delivery_from']))  # noqa: E501
        if local_var_params.get('delivery_to') is not None:  # noqa: E501
            query_params.append(('delivery_to', local_var_params['delivery_to']))  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_security']  # noqa: E501

        response_types_map = {
            200: "Report",
        }

        return self.api_client.call_api(
            '/report/{delivery_area}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def get_schedule_xml(self, delivery_area, delivery_day, member_eic, exchange_eic, receiver_eic, process_type, sender_role, receiver_role, **kwargs):  # noqa: E501
        """Create Schedule XML  # noqa: E501

        Create a delivery area internal schedule XML file for the nomination toward the TSO. Supported formats are ESS (v2.3) and CIM (v5.2), only including the schedule between the exchange member and the member. The revision will be increased with every request performed. You need to provide the EIC of the exchange member as well as the EIC of the exchange.  For a detailed documentation and example values for different countries, please refer to the [Knowledge Base](https://docs.powerbot-trading.com/docs/features/nomination-schedules/).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_schedule_xml(delivery_area, delivery_day, member_eic, exchange_eic, receiver_eic, process_type, sender_role, receiver_role, async_req=True)
        >>> result = thread.get()

        :param delivery_area: The EIC of the delivery area. (required)
        :type delivery_area: str
        :param delivery_day: The day the schedule is for. (required)
        :type delivery_day: date
        :param member_eic: The EIC of the exchange member. (required)
        :type member_eic: str
        :param exchange_eic: The EIC of the exchange. (required)
        :type exchange_eic: str
        :param receiver_eic: Receiver EIC (required)
        :type receiver_eic: str
        :param process_type: Process Type Code (required)
        :type process_type: str
        :param sender_role: Sender Role Code (required)
        :type sender_role: str
        :param receiver_role: Receiver Role Code (required)
        :type receiver_role: str
        :param schedule_format:
        :type schedule_format: ScheduleFormat
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: str
        """
        kwargs['_return_http_data_only'] = True
        return self.get_schedule_xml_with_http_info(delivery_area, delivery_day, member_eic, exchange_eic, receiver_eic, process_type, sender_role, receiver_role, **kwargs)  # noqa: E501

    def get_schedule_xml_with_http_info(self, delivery_area, delivery_day, member_eic, exchange_eic, receiver_eic, process_type, sender_role, receiver_role, **kwargs):  # noqa: E501
        """Create Schedule XML  # noqa: E501

        Create a delivery area internal schedule XML file for the nomination toward the TSO. Supported formats are ESS (v2.3) and CIM (v5.2), only including the schedule between the exchange member and the member. The revision will be increased with every request performed. You need to provide the EIC of the exchange member as well as the EIC of the exchange.  For a detailed documentation and example values for different countries, please refer to the [Knowledge Base](https://docs.powerbot-trading.com/docs/features/nomination-schedules/).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_schedule_xml_with_http_info(delivery_area, delivery_day, member_eic, exchange_eic, receiver_eic, process_type, sender_role, receiver_role, async_req=True)
        >>> result = thread.get()

        :param delivery_area: The EIC of the delivery area. (required)
        :type delivery_area: str
        :param delivery_day: The day the schedule is for. (required)
        :type delivery_day: date
        :param member_eic: The EIC of the exchange member. (required)
        :type member_eic: str
        :param exchange_eic: The EIC of the exchange. (required)
        :type exchange_eic: str
        :param receiver_eic: Receiver EIC (required)
        :type receiver_eic: str
        :param process_type: Process Type Code (required)
        :type process_type: str
        :param sender_role: Sender Role Code (required)
        :type sender_role: str
        :param receiver_role: Receiver Role Code (required)
        :type receiver_role: str
        :param schedule_format:
        :type schedule_format: ScheduleFormat
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(str, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'delivery_area',
            'delivery_day',
            'member_eic',
            'exchange_eic',
            'receiver_eic',
            'process_type',
            'sender_role',
            'receiver_role',
            'schedule_format'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_schedule_xml" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'delivery_area' is set
        if self.api_client.client_side_validation and local_var_params.get('delivery_area') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `delivery_area` when calling `get_schedule_xml`")  # noqa: E501
        # verify the required parameter 'delivery_day' is set
        if self.api_client.client_side_validation and local_var_params.get('delivery_day') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `delivery_day` when calling `get_schedule_xml`")  # noqa: E501
        # verify the required parameter 'member_eic' is set
        if self.api_client.client_side_validation and local_var_params.get('member_eic') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `member_eic` when calling `get_schedule_xml`")  # noqa: E501
        # verify the required parameter 'exchange_eic' is set
        if self.api_client.client_side_validation and local_var_params.get('exchange_eic') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `exchange_eic` when calling `get_schedule_xml`")  # noqa: E501
        # verify the required parameter 'receiver_eic' is set
        if self.api_client.client_side_validation and local_var_params.get('receiver_eic') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `receiver_eic` when calling `get_schedule_xml`")  # noqa: E501
        # verify the required parameter 'process_type' is set
        if self.api_client.client_side_validation and local_var_params.get('process_type') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `process_type` when calling `get_schedule_xml`")  # noqa: E501
        # verify the required parameter 'sender_role' is set
        if self.api_client.client_side_validation and local_var_params.get('sender_role') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `sender_role` when calling `get_schedule_xml`")  # noqa: E501
        # verify the required parameter 'receiver_role' is set
        if self.api_client.client_side_validation and local_var_params.get('receiver_role') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `receiver_role` when calling `get_schedule_xml`")  # noqa: E501

        if self.api_client.client_side_validation and ('delivery_area' in local_var_params and  # noqa: E501
                                                        len(local_var_params['delivery_area']) > 16):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `delivery_area` when calling `get_schedule_xml`, length must be less than or equal to `16`")  # noqa: E501
        if self.api_client.client_side_validation and ('delivery_area' in local_var_params and  # noqa: E501
                                                        len(local_var_params['delivery_area']) < 16):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `delivery_area` when calling `get_schedule_xml`, length must be greater than or equal to `16`")  # noqa: E501
        if self.api_client.client_side_validation and ('member_eic' in local_var_params and  # noqa: E501
                                                        len(local_var_params['member_eic']) > 16):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `member_eic` when calling `get_schedule_xml`, length must be less than or equal to `16`")  # noqa: E501
        if self.api_client.client_side_validation and ('member_eic' in local_var_params and  # noqa: E501
                                                        len(local_var_params['member_eic']) < 16):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `member_eic` when calling `get_schedule_xml`, length must be greater than or equal to `16`")  # noqa: E501
        if self.api_client.client_side_validation and ('exchange_eic' in local_var_params and  # noqa: E501
                                                        len(local_var_params['exchange_eic']) > 16):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `exchange_eic` when calling `get_schedule_xml`, length must be less than or equal to `16`")  # noqa: E501
        if self.api_client.client_side_validation and ('exchange_eic' in local_var_params and  # noqa: E501
                                                        len(local_var_params['exchange_eic']) < 16):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `exchange_eic` when calling `get_schedule_xml`, length must be greater than or equal to `16`")  # noqa: E501
        if self.api_client.client_side_validation and ('receiver_eic' in local_var_params and  # noqa: E501
                                                        len(local_var_params['receiver_eic']) > 16):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `receiver_eic` when calling `get_schedule_xml`, length must be less than or equal to `16`")  # noqa: E501
        if self.api_client.client_side_validation and ('receiver_eic' in local_var_params and  # noqa: E501
                                                        len(local_var_params['receiver_eic']) < 16):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `receiver_eic` when calling `get_schedule_xml`, length must be greater than or equal to `16`")  # noqa: E501
        if self.api_client.client_side_validation and ('process_type' in local_var_params and  # noqa: E501
                                                        len(local_var_params['process_type']) > 3):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `process_type` when calling `get_schedule_xml`, length must be less than or equal to `3`")  # noqa: E501
        if self.api_client.client_side_validation and ('process_type' in local_var_params and  # noqa: E501
                                                        len(local_var_params['process_type']) < 3):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `process_type` when calling `get_schedule_xml`, length must be greater than or equal to `3`")  # noqa: E501
        if self.api_client.client_side_validation and ('sender_role' in local_var_params and  # noqa: E501
                                                        len(local_var_params['sender_role']) > 3):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `sender_role` when calling `get_schedule_xml`, length must be less than or equal to `3`")  # noqa: E501
        if self.api_client.client_side_validation and ('sender_role' in local_var_params and  # noqa: E501
                                                        len(local_var_params['sender_role']) < 3):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `sender_role` when calling `get_schedule_xml`, length must be greater than or equal to `3`")  # noqa: E501
        if self.api_client.client_side_validation and ('receiver_role' in local_var_params and  # noqa: E501
                                                        len(local_var_params['receiver_role']) > 3):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `receiver_role` when calling `get_schedule_xml`, length must be less than or equal to `3`")  # noqa: E501
        if self.api_client.client_side_validation and ('receiver_role' in local_var_params and  # noqa: E501
                                                        len(local_var_params['receiver_role']) < 3):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `receiver_role` when calling `get_schedule_xml`, length must be greater than or equal to `3`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'delivery_area' in local_var_params:
            path_params['delivery_area'] = local_var_params['delivery_area']  # noqa: E501
        if 'delivery_day' in local_var_params:
            path_params['delivery_day'] = local_var_params['delivery_day']  # noqa: E501

        query_params = []
        if local_var_params.get('member_eic') is not None:  # noqa: E501
            query_params.append(('member_eic', local_var_params['member_eic']))  # noqa: E501
        if local_var_params.get('exchange_eic') is not None:  # noqa: E501
            query_params.append(('exchange_eic', local_var_params['exchange_eic']))  # noqa: E501
        if local_var_params.get('receiver_eic') is not None:  # noqa: E501
            query_params.append(('receiver_eic', local_var_params['receiver_eic']))  # noqa: E501
        if local_var_params.get('process_type') is not None:  # noqa: E501
            query_params.append(('process_type', local_var_params['process_type']))  # noqa: E501
        if local_var_params.get('sender_role') is not None:  # noqa: E501
            query_params.append(('sender_role', local_var_params['sender_role']))  # noqa: E501
        if local_var_params.get('receiver_role') is not None:  # noqa: E501
            query_params.append(('receiver_role', local_var_params['receiver_role']))  # noqa: E501
        if local_var_params.get('schedule_format') is not None:  # noqa: E501
            query_params.append(('schedule_format', local_var_params['schedule_format']))  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/xml', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_security']  # noqa: E501

        response_types_map = {
            200: "str",
        }

        return self.api_client.call_api(
            '/schedule/{delivery_area}/{delivery_day}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

# flake8: noqa

"""
    PowerBot - Webservice for algotrading

    # TERMS AND CONDITIONS The PowerBot system provides B2B services for trading at intraday power markets. By using the PowerBot service, each user agrees to the terms and conditions of this licence: 1. The user confirms that they are familiar with the exchanges trading system and all relevant rules, is professionally qualified and in possession of a trading license for the relevant exchange. 2. The user will comply with the exchanges market rules (e.g. [EPEX Spot Market Rules](https://www.epexspot.com/en/downloads#rules-fees-processes) or [Nord Pool Market Rules](https://www.nordpoolgroup.com/trading/Rules-and-regulations/)) and will not endanger the exchange system at any time with heavy load from trading algorithms or by other use. 3. The user is aware of limits imposed by the exchange. 4. The user is solely liable for actions resulting from the use of PowerBot.   # INTRODUCTION PowerBot is a web-based software service enabling algorithmic trading on intraday power exchanges such as EPEX, Nord Pool, HUPX, BSP Southpool, TGE, OPCOM or ETPA. The service is straightforward to integrate in an existing software environment and provides a variety of programming interfaces for development of individual trading algorithms and software tools. Besides enabling fully automated intraday trading, it can be used to create tools for human traders providing relevant information and trading opportunities or can be integrated in existing software tools. For further details see https://www.powerbot-trading.com  ## Knowledge Base In addition to this API guide, please find the documentation at https://docs.powerbot-trading.com - the password will be provided by the PowerBot team. If not, please reach out to us at support@powerbot-trading.com  ## Endpoints The PowerBot service is available at the following REST endpoints:  | Instance      | Base URL for REST Endpoints                                      | |---------------|------------------------------------------------------------------| | EPEX          | https://staging.powerbot-trading.com/playground/epex/v2/api      | | Nord Pool     | https://staging.powerbot-trading.com/playground/nordpool/v2/api  | | HUPX          | https://staging.powerbot-trading.com/playground/hupx/v2/api      | | BSP Southpool | https://staging.powerbot-trading.com/playground/southpool/v2/api | | TGE           | https://staging.powerbot-trading.com/playground/tge/v2/api       | | IBEX          | https://staging.powerbot-trading.com/playground/ibex/v2/api      | | CROPEX        | https://staging.powerbot-trading.com/playground/cropex/v2/api    | | OPCOM         | https://staging.powerbot-trading.com/playground/opcom/v2/api     | | ETPA          | https://staging.powerbot-trading.com/playground/etpa/v2/api      | | BRM           | https://staging.powerbot-trading.com/playground/brm/v2/api       |  Access to endpoints is secured via an API Key, which needs to be passed as an \"api_key\" header in each request.   Notes on API Keys:  * API keys are specific to Test, Staging or Production.  * API keys are generated by the system administrator and need to be requested.  ## How to generate API clients (libraries) This OpenAPI specification can be used to generate API clients (programming libraries) for a wide range of programming languages using tools like [OpenAPI Generator](https://openapi-generator.tech/). A detailed guide can be found in the [knowledge base](https://docs.powerbot-trading.com/articles/getting-started/generating-clients/).  ## PowerBot Python client For Python, a ready-made client is also available on PyPI and can be downloaded locally via:  ```shell   pip install powerbot-client ```  ## Errors The API uses standard HTTP status codes to indicate the success or failure of the API call. The body of the response will be in JSON format as follows:  ``` {   \"message\": \"... an error message ...\" } ```  ## Paging The API uses offset and limit parameters for paged operations. An X-Total-Count header is added to responses to indicate the total number of items in a paged response.  ## API Rate Limiting The API limits the number of concurrent calls to 50 - when that limit is reached, the client will receive 503 http status codes (service unavailable) with the following text:  ``` {   \"message\": \"API rate limit exceeded\" } ``` Clients should ensure that they stay within the limit for concurrent API calls.    ## Additional code samples Additional information and code samples demonstrating the use of the API can be found at in our [knowledge base](https://docs.powerbot-trading.com/docs/programmatic-access/)  # noqa: E501

    The version of the OpenAPI document: 2.21.0-rc1
    Contact: office@powerbot-trading.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "2.21.0-rc1"

# import apis into sdk package
from powerbot_asyncio_client.api.alert_api import AlertApi
from powerbot_asyncio_client.api.algorithms_api import AlgorithmsApi
from powerbot_asyncio_client.api.auction_configuration_api import AuctionConfigurationApi
from powerbot_asyncio_client.api.auction_exchange_api import AuctionExchangeApi
from powerbot_asyncio_client.api.auction_order_api import AuctionOrderApi
from powerbot_asyncio_client.api.auction_settings_api import AuctionSettingsApi
from powerbot_asyncio_client.api.auction_trade_api import AuctionTradeApi
from powerbot_asyncio_client.api.auctions_api import AuctionsApi
from powerbot_asyncio_client.api.authentication_api import AuthenticationApi
from powerbot_asyncio_client.api.capacities_api import CapacitiesApi
from powerbot_asyncio_client.api.contract_api import ContractApi
from powerbot_asyncio_client.api.historic_data_api import HistoricDataApi
from powerbot_asyncio_client.api.logs_api import LogsApi
from powerbot_asyncio_client.api.market_api import MarketApi
from powerbot_asyncio_client.api.messages_api import MessagesApi
from powerbot_asyncio_client.api.orders_api import OrdersApi
from powerbot_asyncio_client.api.portfolios_api import PortfoliosApi
from powerbot_asyncio_client.api.report_api import ReportApi
from powerbot_asyncio_client.api.sso_api import SSOApi
from powerbot_asyncio_client.api.schema_api import SchemaApi
from powerbot_asyncio_client.api.settings_api import SettingsApi
from powerbot_asyncio_client.api.signals_api import SignalsApi
from powerbot_asyncio_client.api.subscriptions_api import SubscriptionsApi
from powerbot_asyncio_client.api.tenants_api import TenantsApi
from powerbot_asyncio_client.api.trades_api import TradesApi

# import ApiClient
from powerbot_asyncio_client.api_client import ApiClient
from powerbot_asyncio_client.configuration import Configuration
from powerbot_asyncio_client.exceptions import OpenApiException
from powerbot_asyncio_client.exceptions import ApiTypeError
from powerbot_asyncio_client.exceptions import ApiValueError
from powerbot_asyncio_client.exceptions import ApiKeyError
from powerbot_asyncio_client.exceptions import ApiAttributeError
from powerbot_asyncio_client.exceptions import ApiException
# import models into sdk package
from powerbot_asyncio_client.models.aggressor_indicator import AggressorIndicator
from powerbot_asyncio_client.models.alert import Alert
from powerbot_asyncio_client.models.alert_notification_policy import AlertNotificationPolicy
from powerbot_asyncio_client.models.algo_command import AlgoCommand
from powerbot_asyncio_client.models.algo_details import AlgoDetails
from powerbot_asyncio_client.models.algo_event import AlgoEvent
from powerbot_asyncio_client.models.algo_heartbeat import AlgoHeartbeat
from powerbot_asyncio_client.models.algo_instance import AlgoInstance
from powerbot_asyncio_client.models.algo_instance_change import AlgoInstanceChange
from powerbot_asyncio_client.models.algo_instance_event import AlgoInstanceEvent
from powerbot_asyncio_client.models.algo_instance_parameters import AlgoInstanceParameters
from powerbot_asyncio_client.models.algo_setup import AlgoSetup
from powerbot_asyncio_client.models.algo_status import AlgoStatus
from powerbot_asyncio_client.models.api_key import ApiKey
from powerbot_asyncio_client.models.api_key_details import ApiKeyDetails
from powerbot_asyncio_client.models.api_key_portfolio_update import ApiKeyPortfolioUpdate
from powerbot_asyncio_client.models.api_key_type import ApiKeyType
from powerbot_asyncio_client.models.atc_status import AtcStatus
from powerbot_asyncio_client.models.auction import Auction
from powerbot_asyncio_client.models.auction_area_result import AuctionAreaResult
from powerbot_asyncio_client.models.auction_area_result_trade import AuctionAreaResultTrade
from powerbot_asyncio_client.models.auction_config import AuctionConfig
from powerbot_asyncio_client.models.auction_constraints import AuctionConstraints
from powerbot_asyncio_client.models.auction_contract import AuctionContract
from powerbot_asyncio_client.models.auction_contract_result import AuctionContractResult
from powerbot_asyncio_client.models.auction_credentials import AuctionCredentials
from powerbot_asyncio_client.models.auction_exchange import AuctionExchange
from powerbot_asyncio_client.models.auction_exchange_portfolio import AuctionExchangePortfolio
from powerbot_asyncio_client.models.auction_exchange_portfolio_currency import AuctionExchangePortfolioCurrency
from powerbot_asyncio_client.models.auction_exchange_portfolio_delivery_area import AuctionExchangePortfolioDeliveryArea
from powerbot_asyncio_client.models.auction_exchange_portfolio_mapping import AuctionExchangePortfolioMapping
from powerbot_asyncio_client.models.auction_limits import AuctionLimits
from powerbot_asyncio_client.models.auction_order import AuctionOrder
from powerbot_asyncio_client.models.auction_order_confirmation import AuctionOrderConfirmation
from powerbot_asyncio_client.models.auction_order_data import AuctionOrderData
from powerbot_asyncio_client.models.auction_order_entry import AuctionOrderEntry
from powerbot_asyncio_client.models.auction_order_state import AuctionOrderState
from powerbot_asyncio_client.models.auction_order_submission_type import AuctionOrderSubmissionType
from powerbot_asyncio_client.models.auction_order_type import AuctionOrderType
from powerbot_asyncio_client.models.auction_positions import AuctionPositions
from powerbot_asyncio_client.models.auction_product_positions import AuctionProductPositions
from powerbot_asyncio_client.models.auction_result import AuctionResult
from powerbot_asyncio_client.models.auction_result_event import AuctionResultEvent
from powerbot_asyncio_client.models.auction_result_state import AuctionResultState
from powerbot_asyncio_client.models.auction_settings import AuctionSettings
from powerbot_asyncio_client.models.auction_state import AuctionState
from powerbot_asyncio_client.models.auction_trade import AuctionTrade
from powerbot_asyncio_client.models.auction_trade_state import AuctionTradeState
from powerbot_asyncio_client.models.auction_trade_submission_type import AuctionTradeSubmissionType
from powerbot_asyncio_client.models.auction_type import AuctionType
from powerbot_asyncio_client.models.audit_log_entry import AuditLogEntry
from powerbot_asyncio_client.models.block import Block
from powerbot_asyncio_client.models.block_period import BlockPeriod
from powerbot_asyncio_client.models.block_state import BlockState
from powerbot_asyncio_client.models.block_type import BlockType
from powerbot_asyncio_client.models.bulk_contract_statistics import BulkContractStatistics
from powerbot_asyncio_client.models.bulk_exports_format import BulkExportsFormat
from powerbot_asyncio_client.models.bulk_exports_response import BulkExportsResponse
from powerbot_asyncio_client.models.bulk_signal import BulkSignal
from powerbot_asyncio_client.models.bulk_signal_response import BulkSignalResponse
from powerbot_asyncio_client.models.capacity import Capacity
from powerbot_asyncio_client.models.capacity_changes import CapacityChanges
from powerbot_asyncio_client.models.cash_limit import CashLimit
from powerbot_asyncio_client.models.certificate import Certificate
from powerbot_asyncio_client.models.changed_credentials import ChangedCredentials
from powerbot_asyncio_client.models.contract import Contract
from powerbot_asyncio_client.models.contract_changed_event import ContractChangedEvent
from powerbot_asyncio_client.models.contract_history_item import ContractHistoryItem
from powerbot_asyncio_client.models.contract_item import ContractItem
from powerbot_asyncio_client.models.contract_reference import ContractReference
from powerbot_asyncio_client.models.contract_statistics import ContractStatistics
from powerbot_asyncio_client.models.contract_type import ContractType
from powerbot_asyncio_client.models.credentials import Credentials
from powerbot_asyncio_client.models.currency_price import CurrencyPrice
from powerbot_asyncio_client.models.curve import Curve
from powerbot_asyncio_client.models.curve_point import CurvePoint
from powerbot_asyncio_client.models.default_account_mapping import DefaultAccountMapping
from powerbot_asyncio_client.models.delivery_area import DeliveryArea
from powerbot_asyncio_client.models.delivery_area_currency_mapping import DeliveryAreaCurrencyMapping
from powerbot_asyncio_client.models.delivery_area_state import DeliveryAreaState
from powerbot_asyncio_client.models.error_response import ErrorResponse
from powerbot_asyncio_client.models.exchange import Exchange
from powerbot_asyncio_client.models.exchange_cash_limit import ExchangeCashLimit
from powerbot_asyncio_client.models.execution_instruction import ExecutionInstruction
from powerbot_asyncio_client.models.historic_orders_response import HistoricOrdersResponse
from powerbot_asyncio_client.models.historic_trades_response import HistoricTradesResponse
from powerbot_asyncio_client.models.ip_allowlist_entry import IPAllowlistEntry
from powerbot_asyncio_client.models.initialization import Initialization
from powerbot_asyncio_client.models.instance_heartbeat_status import InstanceHeartbeatStatus
from powerbot_asyncio_client.models.internal_trade import InternalTrade
from powerbot_asyncio_client.models.limit_violation import LimitViolation
from powerbot_asyncio_client.models.log_entry import LogEntry
from powerbot_asyncio_client.models.log_entry_added import LogEntryAdded
from powerbot_asyncio_client.models.market_mode import MarketMode
from powerbot_asyncio_client.models.market_options import MarketOptions
from powerbot_asyncio_client.models.market_state import MarketState
from powerbot_asyncio_client.models.market_status import MarketStatus
from powerbot_asyncio_client.models.market_status_changed_event import MarketStatusChangedEvent
from powerbot_asyncio_client.models.message import Message
from powerbot_asyncio_client.models.new_api_key import NewApiKey
from powerbot_asyncio_client.models.new_internal_trade import NewInternalTrade
from powerbot_asyncio_client.models.new_portfolio import NewPortfolio
from powerbot_asyncio_client.models.new_sso_provider import NewSsoProvider
from powerbot_asyncio_client.models.new_sso_user import NewSsoUser
from powerbot_asyncio_client.models.new_tenant import NewTenant
from powerbot_asyncio_client.models.notification import Notification
from powerbot_asyncio_client.models.notification_target import NotificationTarget
from powerbot_asyncio_client.models.on_missing_heartbeat import OnMissingHeartbeat
from powerbot_asyncio_client.models.order_action import OrderAction
from powerbot_asyncio_client.models.order_action_quota_limit import OrderActionQuotaLimit
from powerbot_asyncio_client.models.order_book import OrderBook
from powerbot_asyncio_client.models.order_book_bulk_statistics import OrderBookBulkStatistics
from powerbot_asyncio_client.models.order_book_changed_event import OrderBookChangedEvent
from powerbot_asyncio_client.models.order_book_changes import OrderBookChanges
from powerbot_asyncio_client.models.order_book_depth_value import OrderBookDepthValue
from powerbot_asyncio_client.models.order_book_entry import OrderBookEntry
from powerbot_asyncio_client.models.order_book_group import OrderBookGroup
from powerbot_asyncio_client.models.order_book_revision import OrderBookRevision
from powerbot_asyncio_client.models.order_book_statistics import OrderBookStatistics
from powerbot_asyncio_client.models.order_book_statistics_contract import OrderBookStatisticsContract
from powerbot_asyncio_client.models.order_books import OrderBooks
from powerbot_asyncio_client.models.order_count_limit import OrderCountLimit
from powerbot_asyncio_client.models.order_entry import OrderEntry
from powerbot_asyncio_client.models.order_execution_restriction import OrderExecutionRestriction
from powerbot_asyncio_client.models.order_modify import OrderModify
from powerbot_asyncio_client.models.order_modify_item import OrderModifyItem
from powerbot_asyncio_client.models.order_side import OrderSide
from powerbot_asyncio_client.models.order_state import OrderState
from powerbot_asyncio_client.models.order_type import OrderType
from powerbot_asyncio_client.models.orders import Orders
from powerbot_asyncio_client.models.own_order import OwnOrder
from powerbot_asyncio_client.models.own_order_changed_event import OwnOrderChangedEvent
from powerbot_asyncio_client.models.own_order_changes import OwnOrderChanges
from powerbot_asyncio_client.models.own_order_trading_statistics import OwnOrderTradingStatistics
from powerbot_asyncio_client.models.own_trade_changes import OwnTradeChanges
from powerbot_asyncio_client.models.portfolio import Portfolio
from powerbot_asyncio_client.models.portfolio_changes import PortfolioChanges
from powerbot_asyncio_client.models.portfolio_information import PortfolioInformation
from powerbot_asyncio_client.models.portfolio_status import PortfolioStatus
from powerbot_asyncio_client.models.portfolio_type import PortfolioType
from powerbot_asyncio_client.models.position_limit import PositionLimit
from powerbot_asyncio_client.models.position_source import PositionSource
from powerbot_asyncio_client.models.position_source_value import PositionSourceValue
from powerbot_asyncio_client.models.product_information import ProductInformation
from powerbot_asyncio_client.models.public_order_revision import PublicOrderRevision
from powerbot_asyncio_client.models.public_trade import PublicTrade
from powerbot_asyncio_client.models.public_trade_changes import PublicTradeChanges
from powerbot_asyncio_client.models.related_contract import RelatedContract
from powerbot_asyncio_client.models.report import Report
from powerbot_asyncio_client.models.report_element import ReportElement
from powerbot_asyncio_client.models.requests import Requests
from powerbot_asyncio_client.models.resources import Resources
from powerbot_asyncio_client.models.risk_management_settings import RiskManagementSettings
from powerbot_asyncio_client.models.risk_settings_and_portfolio_information import RiskSettingsAndPortfolioInformation
from powerbot_asyncio_client.models.rolling_window_count import RollingWindowCount
from powerbot_asyncio_client.models.save_settings import SaveSettings
from powerbot_asyncio_client.models.schedule_format import ScheduleFormat
from powerbot_asyncio_client.models.self_trade_selector import SelfTradeSelector
from powerbot_asyncio_client.models.settings import Settings
from powerbot_asyncio_client.models.severity import Severity
from powerbot_asyncio_client.models.signal import Signal
from powerbot_asyncio_client.models.signal_changes import SignalChanges
from powerbot_asyncio_client.models.signal_entry import SignalEntry
from powerbot_asyncio_client.models.signal_entry_response import SignalEntryResponse
from powerbot_asyncio_client.models.signal_entry_result import SignalEntryResult
from powerbot_asyncio_client.models.signal_search_item import SignalSearchItem
from powerbot_asyncio_client.models.signal_search_result import SignalSearchResult
from powerbot_asyncio_client.models.signal_source_durations import SignalSourceDurations
from powerbot_asyncio_client.models.signal_time_slice import SignalTimeSlice
from powerbot_asyncio_client.models.sso_provider_organization import SsoProviderOrganization
from powerbot_asyncio_client.models.sso_provider_overview import SsoProviderOverview
from powerbot_asyncio_client.models.sso_provider_overview_item import SsoProviderOverviewItem
from powerbot_asyncio_client.models.sso_provider_update import SsoProviderUpdate
from powerbot_asyncio_client.models.subscription_endpoint import SubscriptionEndpoint
from powerbot_asyncio_client.models.tag_matcher import TagMatcher
from powerbot_asyncio_client.models.tenant import Tenant
from powerbot_asyncio_client.models.text_matching_mode import TextMatchingMode
from powerbot_asyncio_client.models.time_slice_entry import TimeSliceEntry
from powerbot_asyncio_client.models.trade import Trade
from powerbot_asyncio_client.models.trade_changed_event import TradeChangedEvent
from powerbot_asyncio_client.models.trade_state import TradeState
from powerbot_asyncio_client.models.trading_area import TradingArea
from powerbot_asyncio_client.models.update_algo_setup import UpdateAlgoSetup
from powerbot_asyncio_client.models.update_instance_request import UpdateInstanceRequest
from powerbot_asyncio_client.models.update_status import UpdateStatus
from powerbot_asyncio_client.models.updated_api_key import UpdatedApiKey
from powerbot_asyncio_client.models.updated_portfolio import UpdatedPortfolio
from powerbot_asyncio_client.models.updated_sso_user import UpdatedSsoUser
from powerbot_asyncio_client.models.updated_tenant import UpdatedTenant
from powerbot_asyncio_client.models.validation_schema import ValidationSchema
from powerbot_asyncio_client.models.validation_schema_type import ValidationSchemaType
from powerbot_asyncio_client.models.validity_restriction import ValidityRestriction




# coding: utf-8

"""
    PowerBot - Webservice for algotrading

    # TERMS AND CONDITIONS The PowerBot system provides B2B services for trading at intraday power markets. By using the PowerBot service, each user agrees to the terms and conditions of this licence: 1. The user confirms that they are familiar with the exchanges trading system and all relevant rules, is professionally qualified and in possession of a trading license for the relevant exchange. 2. The user will comply with the exchanges market rules (e.g. [EPEX Spot Market Rules](https://www.epexspot.com/en/downloads#rules-fees-processes) or [Nord Pool Market Rules](https://www.nordpoolgroup.com/trading/Rules-and-regulations/)) and will not endanger the exchange system at any time with heavy load from trading algorithms or by other use. 3. The user is aware of limits imposed by the exchange. 4. The user is solely liable for actions resulting from the use of PowerBot.   # INTRODUCTION PowerBot is a web-based software service enabling algorithmic trading on intraday power exchanges such as EPEX, Nord Pool, HUPX, BSP Southpool, TGE, OPCOM or ETPA. The service is straightforward to integrate in an existing software environment and provides a variety of programming interfaces for development of individual trading algorithms and software tools. Besides enabling fully automated intraday trading, it can be used to create tools for human traders providing relevant information and trading opportunities or can be integrated in existing software tools. For further details see https://www.powerbot-trading.com  ## Knowledge Base In addition to this API guide, please find the documentation at https://docs.powerbot-trading.com - the password will be provided by the PowerBot team. If not, please reach out to us at support@powerbot-trading.com  ## Endpoints The PowerBot service is available at the following REST endpoints:  | Instance      | Base URL for REST Endpoints                                      | |---------------|------------------------------------------------------------------| | EPEX          | https://staging.powerbot-trading.com/playground/epex/v2/api      | | Nord Pool     | https://staging.powerbot-trading.com/playground/nordpool/v2/api  | | HUPX          | https://staging.powerbot-trading.com/playground/hupx/v2/api      | | BSP Southpool | https://staging.powerbot-trading.com/playground/southpool/v2/api | | TGE           | https://staging.powerbot-trading.com/playground/tge/v2/api       | | IBEX          | https://staging.powerbot-trading.com/playground/ibex/v2/api      | | CROPEX        | https://staging.powerbot-trading.com/playground/cropex/v2/api    | | OPCOM         | https://staging.powerbot-trading.com/playground/opcom/v2/api     | | ETPA          | https://staging.powerbot-trading.com/playground/etpa/v2/api      | | BRM           | https://staging.powerbot-trading.com/playground/brm/v2/api       |  Access to endpoints is secured via an API Key, which needs to be passed as an \"api_key\" header in each request.   Notes on API Keys:  * API keys are specific to Test, Staging or Production.  * API keys are generated by the system administrator and need to be requested.  ## How to generate API clients (libraries) This OpenAPI specification can be used to generate API clients (programming libraries) for a wide range of programming languages using tools like [OpenAPI Generator](https://openapi-generator.tech/). A detailed guide can be found in the [knowledge base](https://docs.powerbot-trading.com/articles/getting-started/generating-clients/).  ## PowerBot Python client For Python, a ready-made client is also available on PyPI and can be downloaded locally via:  ```shell   pip install powerbot-client ```  ## Errors The API uses standard HTTP status codes to indicate the success or failure of the API call. The body of the response will be in JSON format as follows:  ``` {   \"message\": \"... an error message ...\" } ```  ## Paging The API uses offset and limit parameters for paged operations. An X-Total-Count header is added to responses to indicate the total number of items in a paged response.  ## API Rate Limiting The API limits the number of concurrent calls to 50 - when that limit is reached, the client will receive 503 http status codes (service unavailable) with the following text:  ``` {   \"message\": \"API rate limit exceeded\" } ``` Clients should ensure that they stay within the limit for concurrent API calls.    ## Additional code samples Additional information and code samples demonstrating the use of the API can be found at in our [knowledge base](https://docs.powerbot-trading.com/docs/programmatic-access/)  # noqa: E501

    The version of the OpenAPI document: 2.21.0-rc1
    Contact: office@powerbot-trading.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from powerbot_asyncio_client.api_client import ApiClient
from powerbot_asyncio_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AuctionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_auction_constraints(self, exchange_id, auction_id, delivery_area, portfolio_id, **kwargs):  # noqa: E501
        """Get auction constraints  # noqa: E501

        Returns the price constraints of the specified auction  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_auction_constraints(exchange_id, auction_id, delivery_area, portfolio_id, async_req=True)
        >>> result = thread.get()

        :param exchange_id: (required)
        :type exchange_id: Exchange
        :param auction_id: (required)
        :type auction_id: str
        :param delivery_area: (required)
        :type delivery_area: str
        :param portfolio_id: (required)
        :type portfolio_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AuctionConstraints
        """
        kwargs['_return_http_data_only'] = True
        return self.get_auction_constraints_with_http_info(exchange_id, auction_id, delivery_area, portfolio_id, **kwargs)  # noqa: E501

    def get_auction_constraints_with_http_info(self, exchange_id, auction_id, delivery_area, portfolio_id, **kwargs):  # noqa: E501
        """Get auction constraints  # noqa: E501

        Returns the price constraints of the specified auction  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_auction_constraints_with_http_info(exchange_id, auction_id, delivery_area, portfolio_id, async_req=True)
        >>> result = thread.get()

        :param exchange_id: (required)
        :type exchange_id: Exchange
        :param auction_id: (required)
        :type auction_id: str
        :param delivery_area: (required)
        :type delivery_area: str
        :param portfolio_id: (required)
        :type portfolio_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AuctionConstraints, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'exchange_id',
            'auction_id',
            'delivery_area',
            'portfolio_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_auction_constraints" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'exchange_id' is set
        if self.api_client.client_side_validation and local_var_params.get('exchange_id') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `exchange_id` when calling `get_auction_constraints`")  # noqa: E501
        # verify the required parameter 'auction_id' is set
        if self.api_client.client_side_validation and local_var_params.get('auction_id') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `auction_id` when calling `get_auction_constraints`")  # noqa: E501
        # verify the required parameter 'delivery_area' is set
        if self.api_client.client_side_validation and local_var_params.get('delivery_area') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `delivery_area` when calling `get_auction_constraints`")  # noqa: E501
        # verify the required parameter 'portfolio_id' is set
        if self.api_client.client_side_validation and local_var_params.get('portfolio_id') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `portfolio_id` when calling `get_auction_constraints`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'exchange_id' in local_var_params:
            path_params['exchange_id'] = local_var_params['exchange_id']  # noqa: E501
        if 'auction_id' in local_var_params:
            path_params['auction_id'] = local_var_params['auction_id']  # noqa: E501
        if 'delivery_area' in local_var_params:
            path_params['delivery_area'] = local_var_params['delivery_area']  # noqa: E501
        if 'portfolio_id' in local_var_params:
            path_params['portfolio_id'] = local_var_params['portfolio_id']  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_security']  # noqa: E501

        response_types_map = {
            200: "AuctionConstraints",
        }

        return self.api_client.call_api(
            '/auction/{exchange_id}/{auction_id}/{delivery_area}/{portfolio_id}/constraints', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def get_auction_results(self, exchange_id, auction_ids, **kwargs):  # noqa: E501
        """Get Auction Results  # noqa: E501

        Returns the auction results for the provided parameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_auction_results(exchange_id, auction_ids, async_req=True)
        >>> result = thread.get()

        :param exchange_id: (required)
        :type exchange_id: Exchange
        :param auction_ids: The IDs of the auctions (required)
        :type auction_ids: list[str]
        :param delivery_areas: The delivery areas that should be contained by the auctions
        :type delivery_areas: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[AuctionResult]
        """
        kwargs['_return_http_data_only'] = True
        return self.get_auction_results_with_http_info(exchange_id, auction_ids, **kwargs)  # noqa: E501

    def get_auction_results_with_http_info(self, exchange_id, auction_ids, **kwargs):  # noqa: E501
        """Get Auction Results  # noqa: E501

        Returns the auction results for the provided parameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_auction_results_with_http_info(exchange_id, auction_ids, async_req=True)
        >>> result = thread.get()

        :param exchange_id: (required)
        :type exchange_id: Exchange
        :param auction_ids: The IDs of the auctions (required)
        :type auction_ids: list[str]
        :param delivery_areas: The delivery areas that should be contained by the auctions
        :type delivery_areas: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(list[AuctionResult], status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'exchange_id',
            'auction_ids',
            'delivery_areas'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_auction_results" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'exchange_id' is set
        if self.api_client.client_side_validation and local_var_params.get('exchange_id') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `exchange_id` when calling `get_auction_results`")  # noqa: E501
        # verify the required parameter 'auction_ids' is set
        if self.api_client.client_side_validation and local_var_params.get('auction_ids') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `auction_ids` when calling `get_auction_results`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'exchange_id' in local_var_params:
            path_params['exchange_id'] = local_var_params['exchange_id']  # noqa: E501

        query_params = []
        if local_var_params.get('auction_ids') is not None:  # noqa: E501
            query_params.append(('auction_ids', local_var_params['auction_ids']))  # noqa: E501
            collection_formats['auction_ids'] = 'multi'  # noqa: E501
        if local_var_params.get('delivery_areas') is not None:  # noqa: E501
            query_params.append(('delivery_areas', local_var_params['delivery_areas']))  # noqa: E501
            collection_formats['delivery_areas'] = 'multi'  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_security']  # noqa: E501

        response_types_map = {
            200: "list[AuctionResult]",
        }

        return self.api_client.call_api(
            '/auction/{exchange_id}/auctions/results', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def list_auctions(self, exchange_id, **kwargs):  # noqa: E501
        """List Auctions  # noqa: E501

        Returns all auctions for the provided parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_auctions(exchange_id, async_req=True)
        >>> result = thread.get()

        :param exchange_id: (required)
        :type exchange_id: Exchange
        :param delivery_areas: This filter applies to auctions and auction contracts.
        :type delivery_areas: list[str]
        :param delivery_from: The starting point of the delivery period.
        :type delivery_from: datetime
        :param delivery_to: The end point of the delivery period.
        :type delivery_to: datetime
        :param auction_ids: The IDs of the auctions.
        :type auction_ids: list[str]
        :param gate_closure_from: The start time in which the auctions gate closure time should be contained.
        :type gate_closure_from: datetime
        :param gate_closure_to: The end time in which the auctions gate closure time should be contained.
        :type gate_closure_to: datetime
        :param portfolio_ids: limit the results to auctions that are available to the provided portfolios
        :type portfolio_ids: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[Auction]
        """
        kwargs['_return_http_data_only'] = True
        return self.list_auctions_with_http_info(exchange_id, **kwargs)  # noqa: E501

    def list_auctions_with_http_info(self, exchange_id, **kwargs):  # noqa: E501
        """List Auctions  # noqa: E501

        Returns all auctions for the provided parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_auctions_with_http_info(exchange_id, async_req=True)
        >>> result = thread.get()

        :param exchange_id: (required)
        :type exchange_id: Exchange
        :param delivery_areas: This filter applies to auctions and auction contracts.
        :type delivery_areas: list[str]
        :param delivery_from: The starting point of the delivery period.
        :type delivery_from: datetime
        :param delivery_to: The end point of the delivery period.
        :type delivery_to: datetime
        :param auction_ids: The IDs of the auctions.
        :type auction_ids: list[str]
        :param gate_closure_from: The start time in which the auctions gate closure time should be contained.
        :type gate_closure_from: datetime
        :param gate_closure_to: The end time in which the auctions gate closure time should be contained.
        :type gate_closure_to: datetime
        :param portfolio_ids: limit the results to auctions that are available to the provided portfolios
        :type portfolio_ids: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(list[Auction], status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'exchange_id',
            'delivery_areas',
            'delivery_from',
            'delivery_to',
            'auction_ids',
            'gate_closure_from',
            'gate_closure_to',
            'portfolio_ids'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_auctions" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'exchange_id' is set
        if self.api_client.client_side_validation and local_var_params.get('exchange_id') is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `exchange_id` when calling `list_auctions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'exchange_id' in local_var_params:
            path_params['exchange_id'] = local_var_params['exchange_id']  # noqa: E501

        query_params = []
        if local_var_params.get('delivery_areas') is not None:  # noqa: E501
            query_params.append(('delivery_areas', local_var_params['delivery_areas']))  # noqa: E501
            collection_formats['delivery_areas'] = 'multi'  # noqa: E501
        if local_var_params.get('delivery_from') is not None:  # noqa: E501
            query_params.append(('delivery_from', local_var_params['delivery_from']))  # noqa: E501
        if local_var_params.get('delivery_to') is not None:  # noqa: E501
            query_params.append(('delivery_to', local_var_params['delivery_to']))  # noqa: E501
        if local_var_params.get('auction_ids') is not None:  # noqa: E501
            query_params.append(('auction_ids', local_var_params['auction_ids']))  # noqa: E501
            collection_formats['auction_ids'] = 'multi'  # noqa: E501
        if local_var_params.get('gate_closure_from') is not None:  # noqa: E501
            query_params.append(('gate_closure_from', local_var_params['gate_closure_from']))  # noqa: E501
        if local_var_params.get('gate_closure_to') is not None:  # noqa: E501
            query_params.append(('gate_closure_to', local_var_params['gate_closure_to']))  # noqa: E501
        if local_var_params.get('portfolio_ids') is not None:  # noqa: E501
            query_params.append(('portfolio_ids', local_var_params['portfolio_ids']))  # noqa: E501
            collection_formats['portfolio_ids'] = 'multi'  # noqa: E501

        header_params = dict(local_var_params.get('_headers', {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_security']  # noqa: E501

        response_types_map = {
            200: "list[Auction]",
        }

        return self.api_client.call_api(
            '/auction/{exchange_id}/auctions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    PowerBot - Webservice for algotrading

    # TERMS AND CONDITIONS The PowerBot system provides B2B services for trading at intraday power markets. By using the PowerBot service, each user agrees to the terms and conditions of this licence: 1. The user confirms that they are familiar with the exchanges trading system and all relevant rules, is professionally qualified and in possession of a trading license for the relevant exchange. 2. The user will comply with the exchanges market rules (e.g. [EPEX Spot Market Rules](https://www.epexspot.com/en/downloads#rules-fees-processes) or [Nord Pool Market Rules](https://www.nordpoolgroup.com/trading/Rules-and-regulations/)) and will not endanger the exchange system at any time with heavy load from trading algorithms or by other use. 3. The user is aware of limits imposed by the exchange. 4. The user is solely liable for actions resulting from the use of PowerBot.   # INTRODUCTION PowerBot is a web-based software service enabling algorithmic trading on intraday power exchanges such as EPEX, Nord Pool, HUPX, BSP Southpool, TGE, OPCOM or ETPA. The service is straightforward to integrate in an existing software environment and provides a variety of programming interfaces for development of individual trading algorithms and software tools. Besides enabling fully automated intraday trading, it can be used to create tools for human traders providing relevant information and trading opportunities or can be integrated in existing software tools. For further details see https://www.powerbot-trading.com  ## Knowledge Base In addition to this API guide, please find the documentation at https://docs.powerbot-trading.com - the password will be provided by the PowerBot team. If not, please reach out to us at support@powerbot-trading.com  ## Endpoints The PowerBot service is available at the following REST endpoints:  | Instance      | Base URL for REST Endpoints                                      | |---------------|------------------------------------------------------------------| | EPEX          | https://staging.powerbot-trading.com/playground/epex/v2/api      | | Nord Pool     | https://staging.powerbot-trading.com/playground/nordpool/v2/api  | | HUPX          | https://staging.powerbot-trading.com/playground/hupx/v2/api      | | BSP Southpool | https://staging.powerbot-trading.com/playground/southpool/v2/api | | TGE           | https://staging.powerbot-trading.com/playground/tge/v2/api       | | IBEX          | https://staging.powerbot-trading.com/playground/ibex/v2/api      | | CROPEX        | https://staging.powerbot-trading.com/playground/cropex/v2/api    | | OPCOM         | https://staging.powerbot-trading.com/playground/opcom/v2/api     | | ETPA          | https://staging.powerbot-trading.com/playground/etpa/v2/api      | | BRM           | https://staging.powerbot-trading.com/playground/brm/v2/api       |  Access to endpoints is secured via an API Key, which needs to be passed as an \"api_key\" header in each request.   Notes on API Keys:  * API keys are specific to Test, Staging or Production.  * API keys are generated by the system administrator and need to be requested.  ## How to generate API clients (libraries) This OpenAPI specification can be used to generate API clients (programming libraries) for a wide range of programming languages using tools like [OpenAPI Generator](https://openapi-generator.tech/). A detailed guide can be found in the [knowledge base](https://docs.powerbot-trading.com/articles/getting-started/generating-clients/).  ## PowerBot Python client For Python, a ready-made client is also available on PyPI and can be downloaded locally via:  ```shell   pip install powerbot-client ```  ## Errors The API uses standard HTTP status codes to indicate the success or failure of the API call. The body of the response will be in JSON format as follows:  ``` {   \"message\": \"... an error message ...\" } ```  ## Paging The API uses offset and limit parameters for paged operations. An X-Total-Count header is added to responses to indicate the total number of items in a paged response.  ## API Rate Limiting The API limits the number of concurrent calls to 50 - when that limit is reached, the client will receive 503 http status codes (service unavailable) with the following text:  ``` {   \"message\": \"API rate limit exceeded\" } ``` Clients should ensure that they stay within the limit for concurrent API calls.    ## Additional code samples Additional information and code samples demonstrating the use of the API can be found at in our [knowledge base](https://docs.powerbot-trading.com/docs/programmatic-access/)  # noqa: E501

    The version of the OpenAPI document: 2.21.0-rc1
    Contact: office@powerbot-trading.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from powerbot_asyncio_client.configuration import Configuration


class OrderBookChangedEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message_class': 'str',
        'portfolio_id': 'str',
        'emitted_at': 'datetime',
        'contract_id': 'str',
        'contract_type': 'ContractType',
        'delivery_area': 'str',
        'delivery_start': 'datetime',
        'delivery_end': 'datetime',
        'active_since': 'datetime',
        'revision': 'int',
        'sequence_number': 'int',
        'best_price_changed': 'bool',
        'best_bid_price_changed': 'bool',
        'best_ask_price_changed': 'bool',
        'best_bid_quantity_changed': 'bool',
        'best_ask_quantity_changed': 'bool',
        'product': 'str'
    }

    attribute_map = {
        'message_class': 'messageClass',
        'portfolio_id': 'portfolio_id',
        'emitted_at': 'emittedAt',
        'contract_id': 'contract_id',
        'contract_type': 'contract_type',
        'delivery_area': 'delivery_area',
        'delivery_start': 'delivery_start',
        'delivery_end': 'delivery_end',
        'active_since': 'active_since',
        'revision': 'revision',
        'sequence_number': 'sequence_number',
        'best_price_changed': 'best_price_changed',
        'best_bid_price_changed': 'best_bid_price_changed',
        'best_ask_price_changed': 'best_ask_price_changed',
        'best_bid_quantity_changed': 'best_bid_quantity_changed',
        'best_ask_quantity_changed': 'best_ask_quantity_changed',
        'product': 'product'
    }

    def __init__(self, message_class=None, portfolio_id=None, emitted_at=None, contract_id=None, contract_type=None, delivery_area=None, delivery_start=None, delivery_end=None, active_since=None, revision=None, sequence_number=None, best_price_changed=None, best_bid_price_changed=None, best_ask_price_changed=None, best_bid_quantity_changed=None, best_ask_quantity_changed=None, product=None, local_vars_configuration=None):  # noqa: E501
        """OrderBookChangedEvent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._message_class = None
        self._portfolio_id = None
        self._emitted_at = None
        self._contract_id = None
        self._contract_type = None
        self._delivery_area = None
        self._delivery_start = None
        self._delivery_end = None
        self._active_since = None
        self._revision = None
        self._sequence_number = None
        self._best_price_changed = None
        self._best_bid_price_changed = None
        self._best_ask_price_changed = None
        self._best_bid_quantity_changed = None
        self._best_ask_quantity_changed = None
        self._product = None
        self.discriminator = None

        if message_class is not None:
            self.message_class = message_class
        if portfolio_id is not None:
            self.portfolio_id = portfolio_id
        if emitted_at is not None:
            self.emitted_at = emitted_at
        if contract_id is not None:
            self.contract_id = contract_id
        if contract_type is not None:
            self.contract_type = contract_type
        if delivery_area is not None:
            self.delivery_area = delivery_area
        if delivery_start is not None:
            self.delivery_start = delivery_start
        if delivery_end is not None:
            self.delivery_end = delivery_end
        if active_since is not None:
            self.active_since = active_since
        if revision is not None:
            self.revision = revision
        if sequence_number is not None:
            self.sequence_number = sequence_number
        if best_price_changed is not None:
            self.best_price_changed = best_price_changed
        if best_bid_price_changed is not None:
            self.best_bid_price_changed = best_bid_price_changed
        if best_ask_price_changed is not None:
            self.best_ask_price_changed = best_ask_price_changed
        if best_bid_quantity_changed is not None:
            self.best_bid_quantity_changed = best_bid_quantity_changed
        if best_ask_quantity_changed is not None:
            self.best_ask_quantity_changed = best_ask_quantity_changed
        if product is not None:
            self.product = product

    @property
    def message_class(self):
        """Gets the message_class of this OrderBookChangedEvent.  # noqa: E501


        :return: The message_class of this OrderBookChangedEvent.  # noqa: E501
        :rtype: str
        """
        return self._message_class

    @message_class.setter
    def message_class(self, message_class):
        """Sets the message_class of this OrderBookChangedEvent.


        :param message_class: The message_class of this OrderBookChangedEvent.  # noqa: E501
        :type message_class: str
        """

        self._message_class = message_class

    @property
    def portfolio_id(self):
        """Gets the portfolio_id of this OrderBookChangedEvent.  # noqa: E501


        :return: The portfolio_id of this OrderBookChangedEvent.  # noqa: E501
        :rtype: str
        """
        return self._portfolio_id

    @portfolio_id.setter
    def portfolio_id(self, portfolio_id):
        """Sets the portfolio_id of this OrderBookChangedEvent.


        :param portfolio_id: The portfolio_id of this OrderBookChangedEvent.  # noqa: E501
        :type portfolio_id: str
        """

        self._portfolio_id = portfolio_id

    @property
    def emitted_at(self):
        """Gets the emitted_at of this OrderBookChangedEvent.  # noqa: E501


        :return: The emitted_at of this OrderBookChangedEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._emitted_at

    @emitted_at.setter
    def emitted_at(self, emitted_at):
        """Sets the emitted_at of this OrderBookChangedEvent.


        :param emitted_at: The emitted_at of this OrderBookChangedEvent.  # noqa: E501
        :type emitted_at: datetime
        """

        self._emitted_at = emitted_at

    @property
    def contract_id(self):
        """Gets the contract_id of this OrderBookChangedEvent.  # noqa: E501


        :return: The contract_id of this OrderBookChangedEvent.  # noqa: E501
        :rtype: str
        """
        return self._contract_id

    @contract_id.setter
    def contract_id(self, contract_id):
        """Sets the contract_id of this OrderBookChangedEvent.


        :param contract_id: The contract_id of this OrderBookChangedEvent.  # noqa: E501
        :type contract_id: str
        """

        self._contract_id = contract_id

    @property
    def contract_type(self):
        """Gets the contract_type of this OrderBookChangedEvent.  # noqa: E501


        :return: The contract_type of this OrderBookChangedEvent.  # noqa: E501
        :rtype: ContractType
        """
        return self._contract_type

    @contract_type.setter
    def contract_type(self, contract_type):
        """Sets the contract_type of this OrderBookChangedEvent.


        :param contract_type: The contract_type of this OrderBookChangedEvent.  # noqa: E501
        :type contract_type: ContractType
        """

        self._contract_type = contract_type

    @property
    def delivery_area(self):
        """Gets the delivery_area of this OrderBookChangedEvent.  # noqa: E501


        :return: The delivery_area of this OrderBookChangedEvent.  # noqa: E501
        :rtype: str
        """
        return self._delivery_area

    @delivery_area.setter
    def delivery_area(self, delivery_area):
        """Sets the delivery_area of this OrderBookChangedEvent.


        :param delivery_area: The delivery_area of this OrderBookChangedEvent.  # noqa: E501
        :type delivery_area: str
        """

        self._delivery_area = delivery_area

    @property
    def delivery_start(self):
        """Gets the delivery_start of this OrderBookChangedEvent.  # noqa: E501


        :return: The delivery_start of this OrderBookChangedEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_start

    @delivery_start.setter
    def delivery_start(self, delivery_start):
        """Sets the delivery_start of this OrderBookChangedEvent.


        :param delivery_start: The delivery_start of this OrderBookChangedEvent.  # noqa: E501
        :type delivery_start: datetime
        """

        self._delivery_start = delivery_start

    @property
    def delivery_end(self):
        """Gets the delivery_end of this OrderBookChangedEvent.  # noqa: E501


        :return: The delivery_end of this OrderBookChangedEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._delivery_end

    @delivery_end.setter
    def delivery_end(self, delivery_end):
        """Sets the delivery_end of this OrderBookChangedEvent.


        :param delivery_end: The delivery_end of this OrderBookChangedEvent.  # noqa: E501
        :type delivery_end: datetime
        """

        self._delivery_end = delivery_end

    @property
    def active_since(self):
        """Gets the active_since of this OrderBookChangedEvent.  # noqa: E501

        The timestamp (UTC) since when the contract has been observed as active for trading in the corresponding delivery area. Is reset to current time after a system or market outage or after the market was hibernated. Can be used to determine potential low liquidity situations after activation of new contracts or market outages.  # noqa: E501

        :return: The active_since of this OrderBookChangedEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._active_since

    @active_since.setter
    def active_since(self, active_since):
        """Sets the active_since of this OrderBookChangedEvent.

        The timestamp (UTC) since when the contract has been observed as active for trading in the corresponding delivery area. Is reset to current time after a system or market outage or after the market was hibernated. Can be used to determine potential low liquidity situations after activation of new contracts or market outages.  # noqa: E501

        :param active_since: The active_since of this OrderBookChangedEvent.  # noqa: E501
        :type active_since: datetime
        """

        self._active_since = active_since

    @property
    def revision(self):
        """Gets the revision of this OrderBookChangedEvent.  # noqa: E501


        :return: The revision of this OrderBookChangedEvent.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this OrderBookChangedEvent.


        :param revision: The revision of this OrderBookChangedEvent.  # noqa: E501
        :type revision: int
        """

        self._revision = revision

    @property
    def sequence_number(self):
        """Gets the sequence_number of this OrderBookChangedEvent.  # noqa: E501

        DEPRECATED: use revision instead  # noqa: E501

        :return: The sequence_number of this OrderBookChangedEvent.  # noqa: E501
        :rtype: int
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """Sets the sequence_number of this OrderBookChangedEvent.

        DEPRECATED: use revision instead  # noqa: E501

        :param sequence_number: The sequence_number of this OrderBookChangedEvent.  # noqa: E501
        :type sequence_number: int
        """

        self._sequence_number = sequence_number

    @property
    def best_price_changed(self):
        """Gets the best_price_changed of this OrderBookChangedEvent.  # noqa: E501

        True if the best ask or best bid order changed.  # noqa: E501

        :return: The best_price_changed of this OrderBookChangedEvent.  # noqa: E501
        :rtype: bool
        """
        return self._best_price_changed

    @best_price_changed.setter
    def best_price_changed(self, best_price_changed):
        """Sets the best_price_changed of this OrderBookChangedEvent.

        True if the best ask or best bid order changed.  # noqa: E501

        :param best_price_changed: The best_price_changed of this OrderBookChangedEvent.  # noqa: E501
        :type best_price_changed: bool
        """

        self._best_price_changed = best_price_changed

    @property
    def best_bid_price_changed(self):
        """Gets the best_bid_price_changed of this OrderBookChangedEvent.  # noqa: E501

        True if the best best bid order changed.  # noqa: E501

        :return: The best_bid_price_changed of this OrderBookChangedEvent.  # noqa: E501
        :rtype: bool
        """
        return self._best_bid_price_changed

    @best_bid_price_changed.setter
    def best_bid_price_changed(self, best_bid_price_changed):
        """Sets the best_bid_price_changed of this OrderBookChangedEvent.

        True if the best best bid order changed.  # noqa: E501

        :param best_bid_price_changed: The best_bid_price_changed of this OrderBookChangedEvent.  # noqa: E501
        :type best_bid_price_changed: bool
        """

        self._best_bid_price_changed = best_bid_price_changed

    @property
    def best_ask_price_changed(self):
        """Gets the best_ask_price_changed of this OrderBookChangedEvent.  # noqa: E501

        True if the best best ask order changed.  # noqa: E501

        :return: The best_ask_price_changed of this OrderBookChangedEvent.  # noqa: E501
        :rtype: bool
        """
        return self._best_ask_price_changed

    @best_ask_price_changed.setter
    def best_ask_price_changed(self, best_ask_price_changed):
        """Sets the best_ask_price_changed of this OrderBookChangedEvent.

        True if the best best ask order changed.  # noqa: E501

        :param best_ask_price_changed: The best_ask_price_changed of this OrderBookChangedEvent.  # noqa: E501
        :type best_ask_price_changed: bool
        """

        self._best_ask_price_changed = best_ask_price_changed

    @property
    def best_bid_quantity_changed(self):
        """Gets the best_bid_quantity_changed of this OrderBookChangedEvent.  # noqa: E501

        True if the quantity of the best bid order changed.  # noqa: E501

        :return: The best_bid_quantity_changed of this OrderBookChangedEvent.  # noqa: E501
        :rtype: bool
        """
        return self._best_bid_quantity_changed

    @best_bid_quantity_changed.setter
    def best_bid_quantity_changed(self, best_bid_quantity_changed):
        """Sets the best_bid_quantity_changed of this OrderBookChangedEvent.

        True if the quantity of the best bid order changed.  # noqa: E501

        :param best_bid_quantity_changed: The best_bid_quantity_changed of this OrderBookChangedEvent.  # noqa: E501
        :type best_bid_quantity_changed: bool
        """

        self._best_bid_quantity_changed = best_bid_quantity_changed

    @property
    def best_ask_quantity_changed(self):
        """Gets the best_ask_quantity_changed of this OrderBookChangedEvent.  # noqa: E501

        True if the quantity of the best ask order changed.  # noqa: E501

        :return: The best_ask_quantity_changed of this OrderBookChangedEvent.  # noqa: E501
        :rtype: bool
        """
        return self._best_ask_quantity_changed

    @best_ask_quantity_changed.setter
    def best_ask_quantity_changed(self, best_ask_quantity_changed):
        """Sets the best_ask_quantity_changed of this OrderBookChangedEvent.

        True if the quantity of the best ask order changed.  # noqa: E501

        :param best_ask_quantity_changed: The best_ask_quantity_changed of this OrderBookChangedEvent.  # noqa: E501
        :type best_ask_quantity_changed: bool
        """

        self._best_ask_quantity_changed = best_ask_quantity_changed

    @property
    def product(self):
        """Gets the product of this OrderBookChangedEvent.  # noqa: E501


        :return: The product of this OrderBookChangedEvent.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this OrderBookChangedEvent.


        :param product: The product of this OrderBookChangedEvent.  # noqa: E501
        :type product: str
        """

        self._product = product

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderBookChangedEvent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrderBookChangedEvent):
            return True

        return self.to_dict() != other.to_dict()
